#
# spec file for package gdb
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 RedHat
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{?qemu_user_space_build}
%global _without_testsuite 1
%endif
%bcond_without testsuite

Summary:        A GNU source-level debugger for C, C++, Fortran and other languages
License:        GPL-3.0-or-later AND GPL-3.0-with-GCC-exception AND LGPL-2.1-or-later AND LGPL-3.0-or-later
Group:          Development/Tools/Debuggers
Name:           gdb

Version:        8.2
Release:        lp150.2.6.1

# The release always contains a leading reserved number, start it at 1.
# `upstream' is not a part of `name' to stay fully rpm dependencies compatible for the testing.

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# Do not provide URL for snapshots as the file lasts there only for 2 days.
# ftp://sourceware.org/pub/gdb/releases/gdb-%{version}.tar.gz
Source:         gdb-%{version}.tar.bz2
Url:            http://gnu.org/software/gdb/

%if "%{scl}" == "devtoolset-1.1"
Obsoletes:      devtoolset-1.0-%{pkg_name}
%endif

# For our convenience
%global gdb_src %{name}-%{version}
%global gdb_build build-%{_target_platform}
%global gdb_docdir %{_docdir}/%{name}-doc

%global have_inproctrace 0
%ifarch %{ix86} x86_64
%global have_inproctrace 1
%endif # %{ix86} x86_64

# Choose python version
%if 0%{?suse_version} >= 1320
%define python python3
%else
%define python python
%endif

# GDB patches have the format `gdb-<version>-bz<red-hat-bz-#>-<desc>.patch'.
# They should be created using patch level 1: diff -up ./gdb (or gdb-6.3/gdb).

#=
#push=Should be pushed upstream.
#maybepush=Should be pushed upstream unless it got obsoleted there.
#fedora=Should stay as a Fedora patch.
#ia64=Drop after RHEL-5 rebases and rebuilds are no longer meaningful.
#fedoratest=Keep it in Fedora only as a regression test safety.
#+ppc=Specific for ppc32/ppc64/ppc*
#+work=Requires some nontrivial work.

# Cleanup any leftover testsuite processes as it may stuck mock(1) builds.
#=push
Source2:        gdb-orphanripper.c

# Man page for gstack(1).
#=push
Source3:        gdb-gstack.man

# /etc/gdbinit (from Debian but with Fedora compliant location).
#=fedora
Source4:        gdbinit

# Provide gdbtui for RHEL-5 and RHEL-6 as it is removed upstream (BZ 797664).
Source6:        gdbtui

# libipt: Intel Processor Trace Decoder Library
%global libipt_version 2.0
Source7:        v%{libipt_version}.tar.gz

# Infrastructure to sync patches from the Fedora rpm
Source10:       patchlist.pl
Source11:       patchname_get.sh
Source12:       baselibs.conf
Source13:       gdb-rpmlintrc

#Fedora Packages begin
Patch1:         gdb-6.3-rh-testversion-20041202.patch
Patch2:         gdb-vla-intel-fortran-strides.patch
Patch3:         gdb-vla-intel-fortran-vla-strings.patch
Patch4:         gdb-vla-intel-stringbt-fix.patch
Patch5:         gdb-6.3-ppc64syscall-20040622.patch
Patch6:         gdb-6.3-ppc64displaysymbol-20041124.patch
Patch7:         gdb-6.3-gstack-20050411.patch
Patch8:         gdb-6.3-test-pie-20050107.patch
Patch9:         gdb-6.3-test-self-20050110.patch
Patch10:        gdb-6.3-test-dtorfix-20050121.patch
Patch11:        gdb-6.3-test-movedir-20050125.patch
Patch12:        gdb-6.3-threaded-watchpoints2-20050225.patch
Patch13:        gdb-6.3-inferior-notification-20050721.patch
Patch14:        gdb-6.3-inheritancetest-20050726.patch
Patch15:        gdb-6.3-readnever-20050907.patch
Patch16:        gdb-6.5-bz203661-emit-relocs.patch
Patch17:        gdb-6.5-bz185337-resolve-tls-without-debuginfo-v2.patch
Patch18:        gdb-6.5-sharedlibrary-path.patch
Patch19:        gdb-6.5-BEA-testsuite.patch
Patch20:        gdb-6.5-last-address-space-byte-test.patch
Patch21:        gdb-6.5-readline-long-line-crash-test.patch
Patch22:        gdb-6.5-bz216711-clone-is-outermost.patch
Patch23:        gdb-6.5-bz218379-ppc-solib-trampoline-test.patch
Patch24:        gdb-6.5-bz218379-solib-trampoline-lookup-lock-fix.patch
Patch25:        gdb-6.5-bz109921-DW_AT_decl_file-test.patch
Patch26:        gdb-6.3-bz140532-ppc-unwinding-test.patch
Patch27:        gdb-6.3-bz202689-exec-from-pthread-test.patch
Patch28:        gdb-6.6-bz230000-power6-disassembly-test.patch
Patch29:        gdb-6.6-bz229517-gcore-without-terminal.patch
Patch30:        gdb-6.6-testsuite-timeouts.patch
Patch31:        gdb-6.6-bz237572-ppc-atomic-sequence-test.patch
Patch32:        gdb-6.6-scheduler_locking-step-is-default.patch
Patch33:        gdb-6.3-attach-see-vdso-test.patch
Patch34:        gdb-6.5-bz243845-stale-testing-zombie-test.patch
Patch35:        gdb-6.6-buildid-locate.patch
Patch36:        gdb-6.6-buildid-locate-solib-missing-ids.patch
Patch37:        gdb-6.6-buildid-locate-rpm.patch
Patch38:        gdb-6.7-charsign-test.patch
Patch39:        gdb-6.7-ppc-clobbered-registers-O2-test.patch
Patch40:        gdb-6.7-testsuite-stable-results.patch
Patch41:        gdb-6.5-ia64-libunwind-leak-test.patch
Patch42:        gdb-6.5-missed-trap-on-step-test.patch
Patch43:        gdb-6.5-gcore-buffer-limit-test.patch
Patch44:        gdb-6.3-mapping-zero-inode-test.patch
Patch45:        gdb-6.3-focus-cmd-prev-test.patch
Patch46:        gdb-6.8-bz442765-threaded-exec-test.patch
Patch47:        gdb-6.8-sparc64-silence-memcpy-check.patch
Patch48:        gdb-6.5-section-num-fixup-test.patch
Patch49:        gdb-6.8-bz436037-reg-no-longer-active.patch
Patch50:        gdb-6.8-watchpoint-conditionals-test.patch
Patch51:        gdb-6.8-bz466901-backtrace-full-prelinked.patch
Patch52:        gdb-simultaneous-step-resume-breakpoint-test.patch
Patch53:        gdb-core-open-vdso-warning.patch
Patch54:        gdb-x86_64-i386-syscall-restart.patch
Patch55:        gdb-bz533176-fortran-omp-step.patch
Patch56:        gdb-follow-child-stale-parent.patch
Patch57:        gdb-ccache-workaround.patch
Patch58:        gdb-archer-pie-addons.patch
Patch59:        gdb-archer-pie-addons-keep-disabled.patch
Patch60:        gdb-lineno-makeup-test.patch
Patch61:        gdb-ppc-power7-test.patch
Patch62:        gdb-bz541866-rwatch-before-run.patch
Patch63:        gdb-moribund-utrace-workaround.patch
Patch64:        gdb-archer-next-over-throw-cxx-exec.patch
Patch65:        gdb-bz601887-dwarf4-rh-test.patch
Patch66:        gdb-6.6-buildid-locate-core-as-arg.patch
Patch67:        gdb-6.6-buildid-locate-rpm-librpm-workaround.patch
Patch68:        gdb-test-bt-cfi-without-die.patch
Patch69:        gdb-bz568248-oom-is-error.patch
Patch70:        gdb-bz634108-solib_address.patch
Patch71:        gdb-test-pid0-core.patch
Patch72:        gdb-test-dw2-aranges.patch
Patch73:        gdb-test-expr-cumulative-archer.patch
Patch74:        gdb-physname-pr11734-test.patch
Patch75:        gdb-physname-pr12273-test.patch
Patch76:        gdb-7.2.50-sparc-add-workaround-to-broken-debug-files.patch
Patch77:        gdb-test-ivy-bridge.patch
Patch78:        gdb-runtest-pie-override.patch
Patch79:        gdb-attach-fail-reasons-5of5.patch
Patch80:        gdb-glibc-strstr-workaround.patch
Patch81:        gdb-rhel5.9-testcase-xlf-var-inside-mod.patch
Patch82:        gdb-rhbz-818343-set-solib-absolute-prefix-testcase.patch
Patch83:        gdb-rhbz795424-bitpos-20of25.patch
Patch84:        gdb-rhbz795424-bitpos-21of25.patch
Patch85:        gdb-rhbz795424-bitpos-22of25.patch
Patch86:        gdb-rhbz795424-bitpos-23of25.patch
Patch87:        gdb-rhbz795424-bitpos-25of25.patch
Patch88:        gdb-rhbz795424-bitpos-25of25-test.patch
Patch89:        gdb-rhbz795424-bitpos-lazyvalue.patch
Patch90:        gdb-rhbz947564-findvar-assertion-frame-failed-testcase.patch
Patch91:        gdb-gnat-dwarf-crash-3of3.patch
Patch92:        gdb-rhbz1007614-memleak-infpy_read_memory-test.patch
Patch93:        gdb-6.6-buildid-locate-misleading-warning-missing-debuginfo-rhbz981154.patch
Patch94:        gdb-archer-vla-tests.patch
Patch95:        gdb-vla-intel-tests.patch
Patch96:        gdb-btrobust.patch
Patch97:        gdb-fortran-frame-string.patch
Patch98:        gdb-python-gil.patch
Patch99:        gdb-rhbz1156192-recursive-dlopen-test.patch
Patch100:       gdb-jit-reader-multilib.patch
Patch101:       gdb-rhbz1149205-catch-syscall-after-fork-test.patch
Patch102:       gdb-rhbz1186476-internal-error-unqualified-name-re-set-test.patch
Patch103:       gdb-rhbz1350436-type-printers-error.patch
Patch104:       gdb-rhbz1084404-ppc64-s390x-wrong-prologue-skip-O2-g-3of3.patch
Patch105:       gdb-bz1219747-attach-kills.patch
Patch106:       gdb-fedora-libncursesw.patch
Patch107:       gdb-opcodes-clflushopt-test.patch
Patch108:       gdb-dts-rhel6-python-compat.patch
Patch109:       gdb-6.6-buildid-locate-rpm-scl.patch
Patch110:       gdb-readline62-ask-more-rh.patch
Patch111:       gdb-6.8-quit-never-aborts.patch
Patch112:       gdb-rhbz1261564-aarch64-hw-watchpoint-test.patch
Patch113:       gdb-container-rh-pkg.patch
Patch114:       gdb-rhbz1325795-framefilters-test.patch
Patch115:       gdb-linux_perf-bundle.patch
Patch116:       gdb-libexec-add-index.patch
Patch117:       gdb-rhbz1398387-tab-crash-test.patch
Patch118:       gdb-testsuite-readline63-sigint.patch
Patch119:       gdb-archer.patch
Patch120:       gdb-vla-intel-fix-print-char-array.patch
Patch121:       gdb-rhbz1553104-s390x-arch12-test.patch
Patch122:       gdb-rhbz881849-ipv6-1of3.patch
Patch123:       gdb-rhbz881849-ipv6-2of3.patch
Patch124:       gdb-rhbz881849-ipv6-3of3.patch
Patch125:       gdb-rhbz1187581-power8-regs-1of7.patch
Patch126:       gdb-rhbz1187581-power8-regs-2of7.patch
Patch127:       gdb-rhbz1187581-power8-regs-3of7.patch
Patch128:       gdb-rhbz1187581-power8-regs-4of7.patch
Patch129:       gdb-rhbz1187581-power8-regs-5of7.patch
Patch130:       gdb-rhbz1187581-power8-regs-6of7.patch
Patch131:       gdb-rhbz1187581-power8-regs-7of7.patch
Patch132:       gdb-rhbz1491128-batch-mode-exit-status-1of2.patch
Patch133:       gdb-rhbz1491128-batch-mode-exit-status-2of2.patch
Patch134:       gdb-use-pulongest-aarch64-linux-tdep.patch
#Fedora Packages end

# Upstream patch to fix gcc -Werror
Patch1002:      gdb-6.6-buildid-locate-rpm-suse.patch
Patch1004:      gdb-fix-buf-overflow.diff
Patch1005:      gdb-7.10-swo18929.patch
Patch1007:      gdb-fix-s390-build.diff

# Backports from master
Patch2000:      gdb-fix-crash-when-reading-core.patch

# libipt support
Patch3000:      v1.5-libipt-static.patch

BuildRequires:  bison
BuildRequires:  flex
%if 0%{suse_version} > 1110
%define gcc gcc
%else
%define gcc gcc48
%endif
BuildRequires:  %{gcc}
BuildRequires:  %{gcc}-c++
BuildRequires:  gettext
BuildRequires:  glibc-devel
%if 0%{suse_version} > 1110 && 0%{suse_version} < 1330
BuildRequires:  guile-devel
%endif
BuildRequires:  ncurses-devel
BuildRequires:  texinfo
%if %{suse_version} < 1020
BuildRequires:  expat
%else
BuildRequires:  libexpat-devel
%endif
BuildRequires:  pkg-config
BuildRequires:  readline-devel
BuildRequires:  rpm-devel
BuildRequires:  zlib-devel
%if 0%{!?_without_python:1}
%if 0%{suse_version} > 1000
Requires:       %{python}-base
%endif
BuildRequires:  %{python}-devel
%endif	# 0%{!?_without_python:1}

%global have_libipt 0
%if 0%{suse_version} > 1110
%ifarch %{ix86} x86_64
%global have_libipt 1
BuildRequires:  cmake
%endif
%endif

# BuildArch would break RHEL-5 by overriding arch and not building noarch.
%if 0%{?el5:1}
ExclusiveArch:  noarch i386 x86_64 ppc ppc64 ia64 s390 s390x
%endif # 0%{?el5:1}

%if %{with testsuite}

# Ensure the devel libraries are installed for both multilib arches.
%global bits_local %{?_isa}
%global bits_other %{?_isa}
%if 0%{!?el5:1}
%ifarch s390x
%global bits_other (%{__isa_name}-32)
%else #!s390x
%ifarch ppc
%global bits_other (%{__isa_name}-64)
%else #!ppc
%ifarch sparc64 ppc64 s390x x86_64
%global bits_other (%{__isa_name}-32)
%endif #sparc64 ppc64 s390x x86_64
%endif #!ppc
%endif #!s390x
%endif #!el5

BuildRequires:  dejagnu
BuildRequires:  sharutils
# gcc-objc++ is not covered by the GDB testsuite.
BuildRequires:  %{gcc}-fortran
%if 0%{?gcc_version} < 7 && 0%{suse_version} > 1110
BuildRequires:  %{gcc}-java
%endif
BuildRequires:  %{gcc}-objc
# Copied from gcc-4.1.2-32.
%ifarch %{ix86} x86_64 ia64 ppc ppc64 s390 alpha
BuildRequires:  %{gcc}-ada
%endif
%ifarch aarch64
%if 0%{suse_version} >= 1330
BuildRequires:  %{gcc}-ada
%endif
%endif
%if 0%{!?disable_32bit:1}
# openSUSE for s390x doesn't build 32bit libs
%if 0%{suse_version} > 1110
%ifarch x86_64 ppc64 s390x
%if 0%{suse_version} >= 1330
# Older distros miss this pseudo package, the Ada
# testsuite won't work completely
BuildRequires:  %{gcc}-ada-32bit
%endif
BuildRequires:  %{gcc}-c++-32bit
%if 0%{suse_version} >= 1210 && 0%{suse_version} != 1315
BuildRequires:  glibc-devel-static-32bit
%endif
%endif
%endif
%endif
%if 0%{suse_version} >= 1210
BuildRequires:  glibc-devel-static
%endif

%endif # %{with testsuite}

%ifarch ia64
BuildRequires:  libunwind-devel
Requires:       libunwind
%endif

%description
GDB, the GNU debugger, allows you to debug programs written in C, C++,
Java, and other languages, by executing them in a controlled fashion
and printing their data.

%if %{suse_version} > 1010
%package -n gdbserver
Summary:        A standalone server for GDB (the GNU source-level debugger)
License:        GPL-3.0-or-later AND GPL-3.0-with-GCC-exception AND LGPL-2.1-or-later AND LGPL-3.0-or-later
Group:          Development/Tools/Debuggers

%description -n gdbserver
GDB, the GNU debugger, allows you to debug programs written in C, C++,
Java, and other languages, by executing them in a controlled fashion
and printing their data.

This package provides a program that allows you to run GDB on a different
machine than the one which is running the program being debugged.
%endif

%package doc
Summary:        Documentation for GDB (the GNU source-level debugger)
License:        GFDL-1.3-only
Group:          Documentation/Other
PreReq:         %{install_info_prereq}

%if "%{scl}" == "devtoolset-1.1"
Obsoletes:      devtoolset-1.0-%{pkg_name}-doc
%endif

%description doc
GDB, the GNU debugger, allows you to debug programs written in C, C++,
Java, and other languages, by executing them in a controlled fashion
and printing their data.

This package provides INFO, HTML and PDF user manual for GDB.

%package testresults
Summary:        GDB testsuite results
License:        SUSE-Public-Domain
Group:          Development/Languages/C and C++

%description testresults
Results from running the GDB testsuite. 

%prep
%setup -q -n %{gdb_src}

%if 0%{?rhel:1} && 0%{?rhel} <= 6
# libstdc++ pretty printers.
tar xjf %{SOURCE5}
%endif # 0%{?rhel:1} && 0%{?rhel} <= 6

# Files have `# <number> <file>' statements breaking VPATH / find-debuginfo.sh .
rm -f gdb/ada-exp.c gdb/ada-lex.c gdb/c-exp.c gdb/cp-name-parser.c gdb/f-exp.c
rm -f gdb/jv-exp.c gdb/m2-exp.c gdb/objc-exp.c gdb/p-exp.c gdb/go-exp.c

# *.info* is needlessly split in the distro tar; also it would not get used as
# we build in %{gdb_build}, just to be sure.
find -name "*.info*"|xargs rm -f

#Fedora patching start
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1
%patch19 -p1
%patch20 -p1
%patch21 -p1
%patch22 -p1
%patch23 -p1
%patch24 -p1
%patch25 -p1
%patch26 -p1
%patch27 -p1
%patch28 -p1
%patch29 -p1
%patch30 -p1
%patch31 -p1
%patch32 -p1
%patch33 -p1
%patch34 -p1
%patch35 -p1
%patch36 -p1
%patch37 -p1
%patch38 -p1
%patch39 -p1
%patch40 -p1
%patch41 -p1
%patch42 -p1
%patch43 -p1
%patch44 -p1
%patch45 -p1
%patch46 -p1
%patch47 -p1
%patch48 -p1
%patch49 -p1
%patch50 -p1
%patch51 -p1
%patch52 -p1
%patch53 -p1
%patch54 -p1
%patch55 -p1
%patch56 -p1
%patch57 -p1
%patch58 -p1
%patch59 -p1
%patch60 -p1
%patch61 -p1
%patch62 -p1
%patch63 -p1
%patch64 -p1
%patch65 -p1
%patch66 -p1
%patch67 -p1
%patch68 -p1
%patch69 -p1
%patch70 -p1
%patch71 -p1
%patch72 -p1
%patch73 -p1
%patch74 -p1
%patch75 -p1
%patch76 -p1
%patch77 -p1
%patch78 -p1
%patch79 -p1
%patch80 -p1
%patch81 -p1
%patch82 -p1
%patch83 -p1
%patch84 -p1
%patch85 -p1
%patch86 -p1
%patch87 -p1
%patch88 -p1
%patch89 -p1
%patch90 -p1
%patch91 -p1
%patch92 -p1
%patch93 -p1
%patch94 -p1
%patch95 -p1
%patch96 -p1
%patch97 -p1
%patch98 -p1
%patch99 -p1
%patch100 -p1
%patch101 -p1
%patch102 -p1
%patch103 -p1
%patch104 -p1
%patch105 -p1
%patch106 -p1
%patch107 -p1
%patch108 -p1
%patch109 -p1
%patch110 -p1
%patch111 -p1
%patch112 -p1
%patch113 -p1
%patch114 -p1
%patch115 -p1
%patch116 -p1
%patch117 -p1
%patch118 -p1
%patch119 -p1
%patch120 -p1
%patch121 -p1
%patch122 -p1
%patch123 -p1
%patch124 -p1
%patch125 -p1
%patch126 -p1
%patch127 -p1
%patch128 -p1
%patch129 -p1
%patch130 -p1
%patch131 -p1
%patch132 -p1
%patch133 -p1
%patch134 -p1
#Fedora patching end

%patch1002 -p1
%patch1004 -p1
%patch1005 -p1
%patch1007 -p1

%patch2000 -p1

#unpack libipt
%if 0%{have_libipt}
tar xzf %{SOURCE7}
(
 cd processor-trace-%{libipt_version}
%patch3000 -p1
)
%endif

find -name "*.orig" | xargs rm -f
! find -name "*.rej" # Should not happen.

# Remove the info and other generated files added by the FSF release
# process.
rm -f libdecnumber/gstdint.h
rm -f bfd/doc/*.info
rm -f bfd/doc/*.info-*
rm -f gdb/doc/*.info
rm -f gdb/doc/*.info-*

%build
rm -rf %{buildroot}

# Identify the build directory with the version of gdb as well as the
# architecture, to allow for mutliple versions to be installed and
# built.
# Initially we're in the %{gdb_src} directory.

for fprofile in %{?_with_profile:-fprofile} ""
do

mkdir %{gdb_build}$fprofile
cd %{gdb_build}$fprofile

%if 0%{suse_version} > 1110
CC=gcc
CXX=g++
%else
CC=gcc-4.8
CXX=g++-4.8
%endif
export CC
export CXX
export CFLAGS="$RPM_OPT_FLAGS"

# FIXME: gcc-7 compatibility.
# checking for acceptance of -Wno-foo is a bit wieldy: GCC doesn't 
# warn about unknown -Wno- flags, _except_ if there are other
# diagnostics as well, so let's force an uninitialized use warning
# and grep for the diagnostic about the -Wno flag:
# -Wno-error=cast-function-type:
# FIXME: gcc-8.0:
# ./elf32-target.h:215:4: error: cast between incompatible function types from 'void * (*)(bfd *)' {aka 'void * (*)(struct bfd *)'} to 'asymbol * (*)(bfd *, void *, long unsigned int)' {aka 'struct bfd_symbol * (*)(struc t bfd *, void *, long unsigned int)'} [-Werror=cast-function-type]
#    ((asymbol * (*) (bfd *, void *, unsigned long)) bfd_nullvoidptr)
# -Wno-error=stringop-truncation:
# FIXME: gcc-8.0:
# linux-tdep.c:1767:11: error: ‘char* strncpy(char*, const char*, size_t)’ specified bound 17 equals destination size [-Werror=stringop-truncation]
#    strncpy (p->pr_fname, basename, sizeof (p->pr_fname));
for opt in -Wno-implicit-fallthrough -Wno-error=cast-function-type -Wno-error=stringop-truncation; do
  if ! echo "int foo(void) { int a; return a;} " | \
     $CC  -x c -c - -o /dev/null -W ${opt} 2>&1 | \
     egrep "Wno|no option" >/dev/null; then
    CFLAGS="$CFLAGS ${opt}"
  fi
done
%if %{have_libipt}
CFLAGS="$CFLAGS -DPERF_ATTR_SIZE_VER5_BUNDLE"
(
 mkdir processor-trace-%{libipt_version}-root
 mkdir processor-trace-%{libipt_version}-build
 cd    processor-trace-%{libipt_version}-build
 # -DPTUNIT:BOOL=ON has no effect on ctest.
 cmake -DCMAKE_INSTALL_PREFIX=/usr -DCMAKE_BUILD_TYPE=RelWithDebInfo \
        -DPTUNIT:BOOL=OFF \
        -DDEVBUILD:BOOL=ON \
        ../../processor-trace-%{libipt_version}
 make VERBOSE=1 %{?_smp_mflags}
 ctest -V %{?_smp_mflags}
 make install DESTDIR=../processor-trace-%{libipt_version}-root
)
# There is also: --with-libipt-prefix
CFLAGS="$CFLAGS -I$PWD/processor-trace-%{libipt_version}-root%{_includedir}"
LDFLAGS="$LDFLAGS -L$PWD/processor-trace-%{libipt_version}-root%{_libdir}"
%endif

export CXXFLAGS="$CFLAGS"

export LIBRPM=no
if test -f /usr/%{_lib}/librpm.so.1; then
  export LIBRPM=librpm.so.1
fi
if test -f /usr/%{_lib}/librpm.so.2; then
  export LIBRPM=librpm.so.2
fi
if test -f /usr/%{_lib}/librpm.so.3; then
  export LIBRPM=librpm.so.3
fi
%ifarch %ix86 ia64 ppc ppc64 ppc64le s390 s390x x86_64 aarch64
%define build_multitarget 1
%else
%define build_multitarget 0
%endif
# For now disable ia64 until ia64-tdep.c is fixed 
%define target_list i686 powerpc powerpc64 powerpc64le s390 s390x x86_64 arm aarch64 m68k
%define DIST %(echo '%distribution' | sed 's, /.*,,')
%if %build_multitarget
EXTRA_TARGETS="%(printf ,%%s-suse-linux %target_list)"
EXTRA_TARGETS="$EXTRA_TARGETS,spu-elf"
%else
EXTRA_TARGETS=
%endif

../configure							\
	--prefix=%{_prefix}					\
	--libdir=%{_libdir}					\
	--sysconfdir=%{_sysconfdir}				\
	--mandir=%{_mandir}					\
	--infodir=%{_infodir}					\
	--htmldir=%{gdb_docdir}					\
	--pdfdir=%{gdb_docdir}					\
	--with-system-gdbinit=%{_sysconfdir}/gdbinit		\
	--with-gdb-datadir=%{_datadir}/gdb			\
	--enable-gdb-build-warnings=,-Wno-unused		\
%ifnarch %{ix86} alpha ia64 ppc s390 s390x x86_64 ppc64 ppc64le sparc sparcv9 sparc64
	--disable-werror					\
%else
%if %{suse_version} <= 1110
	--disable-werror					\
%else
	--enable-werror						\
%endif
%endif
	--with-separate-debug-dir=/usr/lib/debug		\
	--disable-sim						\
	--disable-rpath						\
	--with-system-zlib					\
%if %{suse_version} > 1110
	--with-system-readline					\
%else
	--without-system-readline				\
%endif
	--with-expat						\
$(: ppc64 host build crashes on ppc variant of libexpat.so )	\
	--without-libexpat-prefix				\
	--enable-tui						\
%if 0%{!?_without_python:1}
	--with-python=%{_bindir}/%{python}			\
%else
	--without-python					\
%endif
%if %{suse_version} >= 1130
	--with-rpm=$LIBRPM					\
%else
	--without-rpm						\
%endif
%ifarch ia64
	--with-libunwind					\
%else
	--without-libunwind					\
%endif
%ifarch sparc sparcv9 sparc64
	--without-mmap						\
%endif
	--enable-64-bit-bfd					\
%if %{have_inproctrace}
	--enable-inprocess-agent				\
%else
	--disable-inprocess-agent				\
%endif
%if %{have_libipt}
        --with-intel-pt                                         \
%else
        --without-intel-pt                                      \
%endif
	--with-bugurl=http://bugs.opensuse.org/ \
	--with-pkgversion="GDB; %{DIST}" \
	${EXTRA_TARGETS:+--enable-targets="${EXTRA_TARGETS#,}"} \
%ifarch sparc sparcv9
	--build=sparc-%{_vendor}-%{_target_os}%{?_gnu}
%else
$(: It breaks RHEL-5 by %{_target_platform} being noarch-redhat-linux-gnu ) \
%ifarch noarch
	$(:)
%else
	--build=%{_target_platform}
%endif
%endif

if [ -z "%{!?_with_profile:no}" ]
then
  # Run all the configure tests being incompatible with $FPROFILE_CFLAGS.
  make %{?_smp_mflags} configure-host configure-target
  make %{?_smp_mflags} clean

  # Workaround -fprofile-use:
  # linux-x86-low.c:2225: Error: symbol `start_i386_goto' is already defined
  make %{?_smp_mflags} -C gdb/gdbserver linux-x86-low.o
fi

# Global CFLAGS would fail on:
# conftest.c:1:1: error: coverage mismatch for function 'main' while reading counter 'arcs'
if [ "$fprofile" = "-fprofile" ]
then
  FPROFILE_CFLAGS='-fprofile-generate'
elif [ -z "%{!?_with_profile:no}" ]
then
  FPROFILE_CFLAGS='-fprofile-use'
  # We cannot use -fprofile-dir as the bare filenames clash.
  (cd ../%{gdb_build}-fprofile;
   # It was 333 on x86_64.
   test $(find -name "*.gcda"|wc -l) -gt 300
   find -name "*.gcda" | while read -r i
   do
     ln $i ../%{gdb_build}/$i
   done
  )
else
  FPROFILE_CFLAGS=""
fi

# Prepare gdb/config.h first.
make %{?_smp_mflags} V=1 CFLAGS="$CFLAGS $FPROFILE_CFLAGS" LDFLAGS="$LDFLAGS $FPROFILE_CFLAGS" maybe-configure-gdb
perl -i.relocatable -pe 's/^(D\[".*_RELOCATABLE"\]=" )1(")$/${1}0$2/' gdb/config.status

make %{?_smp_mflags} V=1 CFLAGS="$CFLAGS $FPROFILE_CFLAGS" LDFLAGS="$LDFLAGS $FPROFILE_CFLAGS"

! grep '_RELOCATABLE.*1' gdb/config.h

if [ "$fprofile" = "-fprofile" ]
then
  cd gdb
  cp -p gdb gdb-withindex
  PATH="$PWD:$PATH" sh ../../gdb/gdb-add-index $PWD/gdb-withindex
  ./gdb -nx -ex q ./gdb-withindex
  ./gdb -nx -readnow -ex q ./gdb-withindex
  cd ..
fi

cd ..

done	# fprofile

cd %{gdb_build}

#make %{?_smp_mflags} -C gdb/doc {gdb,annotate}{.info,/index.html,.pdf} MAKEHTMLFLAGS=--no-split

# Copy the <sourcetree>/gdb/NEWS file to the directory above it.
cp $RPM_BUILD_DIR/%{gdb_src}/gdb/NEWS $RPM_BUILD_DIR/%{gdb_src}

%check
# Initially we're in the %{gdb_src} directory.
cd %{gdb_build}

%if %{without testsuite}
echo ====================TESTSUITE DISABLED=========================
%else
echo ====================TESTING=========================
cd gdb
%if 0%{suse_version} > 1110
CC=gcc
CXX=g++
%else
CC=gcc-4.8
CXX=g++-4.8
mkdir progs
for i in gcc g++ gcj gfortran gnat gnatbind gnatmake; do
  test -f /usr/bin/${i}-4.8 && ln -sf /usr/bin/${i}-4.8 progs/$i
done
PATH="`pwd`"/progs:${PATH}
%endif
export CC
export CXX
$CC -o ./orphanripper %{SOURCE2} -Wall -lutil -ggdb2
# Need to use a single --ignore option, second use overrides first.
# No `%{?_smp_mflags}' here as it may race.
# WARNING: can't generate a core file - core tests suppressed - check ulimit
# "readline-overflow.exp" - Testcase is broken, functionality is OK.
(
  # ULIMIT required for `gdb.base/auxv.exp'.
  ulimit -H -c
  ulimit -c unlimited || :

  # Setup $CHECK as `check//unix/' or `check//unix/-m64' for explicit bitsize.
  # Never use two different bitsizes as it fails on ppc64.
  echo 'int main (void) { return 0; }' >biarch.c
  CHECK=""
  for BI in -m64 -m32 -m31 ""
  do
    # Do not use size-less options if any of the sizes works.
    # On ia64 there is no -m64 flag while we must not leave a bare `check' here
    # as it would switch over some testing scripts to the backward compatibility
    # mode: when `make check' was executed from inside the testsuite/ directory.
    if [ -z "$BI" -a -n "$CHECK" ];then
      continue
    fi
    # Do not use $RPM_OPT_FLAGS as the other non-size options will not be used
    # in the real run of the testsuite.
    if ! $CC $BI -o biarch biarch.c
    then
      continue
    fi
    CHECK="$CHECK check//unix/$BI"
  done
  # Do not try -m64 inferiors for -m32 GDB as it cannot handle inferiors larger
  # than itself.
  # s390 -m31 still uses the standard ELF32 binary format.
  $CC $RPM_OPT_FLAGS -o biarch biarch.c
  RPM_SIZE="$(file ./biarch|sed -n 's/^.*: ELF \(32\|64\)-bit .*$/\1/p')"
  if [ "$RPM_SIZE" != "64" ]
  then
    CHECK="$(echo " $CHECK "|sed 's# check//unix/-m64 # #')"
  fi

  # Disable some problematic testcases.
  # RUNTESTFLAGS='--ignore ...' is not used below as it gets separated by the
  # `check//...' target spawn and too much escaping there would be dense.
  for test in				\
    gdb.base/readline-overflow.exp	\
    gdb.base/bigcore.exp		\
    gdb.threads/attach-many-short-lived-threads.exp \
  ; do
    mv -f ../../gdb/testsuite/$test ../../gdb/testsuite/$test-DISABLED || :
  done

  # Run all the scheduled testsuite runs also in the PIE mode.
  # See also: gdb-runtest-pie-override.exp
  CHECK="$(echo $CHECK|sed 's#check//unix/[^ ]*#& &/-fPIC/-pie#g')"

  ./orphanripper make %{?_smp_mflags} -k $CHECK || :
)
for t in sum log
do
  for file in testsuite*/gdb.$t
  do
    suffix="${file#testsuite.unix.}"
    suffix="${suffix%/gdb.$t}"
    ln $file gdb-%{_target_platform}$suffix.$t || :
  done
done
# `tar | bzip2 | uuencode' may have some piping problems in Brew.
#tar cjf gdb-%{_target_platform}.tar.bz2 gdb-%{_target_platform}*.{sum,log}
#uuencode gdb-%{_target_platform}.tar.bz2 gdb-%{_target_platform}.tar.bz2
# Strip dates and completion times from the log to make build-compare happy
sed -i -e '/Test Run By abuild on/d' -e 's/completed in [0-9]* seconds//' *.{sum,log}
cd ../..
echo ====================TESTING END=====================
%endif

%install
# Initially we're in the %{gdb_src} directory.
cd %{gdb_build}

# It would break RHEL-5 by leaving excessive files for the doc subpackage.
%ifnarch noarch

make %{?_smp_mflags} install DESTDIR=$RPM_BUILD_ROOT

# Provide gdbtui for RHEL-5 and RHEL-6 as it is removed upstream (BZ 797664).
%if 0%{?rhel:1} && 0%{?rhel} <= 6
test ! -e $RPM_BUILD_ROOT%{_prefix}/bin/gdbtui
install -m 755 %{SOURCE6} $RPM_BUILD_ROOT%{_prefix}/bin/gdbtui
ln -sf gdb.1 $RPM_BUILD_ROOT%{_mandir}/man1/gdbtui.1
%endif # 0%{?rhel:1} && 0%{?rhel} <= 6

mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/gdbinit.d
touch -r %{SOURCE4} $RPM_BUILD_ROOT%{_sysconfdir}/gdbinit.d
sed 's#%%{_sysconfdir}#%{_sysconfdir}#g' <%{SOURCE4} >$RPM_BUILD_ROOT%{_sysconfdir}/gdbinit
touch -r %{SOURCE4} $RPM_BUILD_ROOT%{_sysconfdir}/gdbinit

for i in `find $RPM_BUILD_ROOT%{_datadir}/gdb/python/gdb -name "*.py"`
do
  # Files could be also patched getting the current time.
  touch -r $RPM_BUILD_DIR/%{gdb_src}/gdb/ChangeLog $i
done

%if 0%{?_enable_debug_packages:1} && 0%{!?_without_python:1}
mkdir -p $RPM_BUILD_ROOT/usr/lib/debug%{_bindir}
cp -p $RPM_BUILD_DIR/%{gdb_src}/gdb/gdb-gdb.py $RPM_BUILD_ROOT/usr/lib/debug%{_bindir}/
for pyo in "" "-O";do
  # RHEL-5: AttributeError: 'module' object has no attribute 'compile_file'
  %{python} $pyo -c 'import compileall, re, sys; sys.exit (not compileall.compile_dir("'"$RPM_BUILD_ROOT/usr/lib/debug%{_bindir}"'", 1, "'"/usr/lib/debug%{_bindir}"'"))'
done
%endif # 0%{?_enable_debug_packages:1} && 0%{!?_without_python:1}

mkdir $RPM_BUILD_ROOT%{_datadir}/gdb/auto-load
%if 0%{?rhel:1} && 0%{?rhel} <= 6
%if 0%{!?_without_python:1}
# Temporarily now:
for LIB in lib lib64;do
  LIBPATH="$RPM_BUILD_ROOT%{_datadir}/gdb/auto-load%{_root_prefix}/$LIB"
  mkdir -p $LIBPATH
  # basename is being run only for the native (non-biarch) file.
  sed -e 's,@pythondir@,%{_datadir}/gdb/python,'		\
      -e 's,@toolexeclibdir@,%{_root_prefix}/'"$LIB,"		\
      < $RPM_BUILD_DIR/%{gdb_src}/%{libstdcxxpython}/hook.in	\
      > $LIBPATH/$(basename %{_root_prefix}/%{_lib}/libstdc++.so.6.*)-gdb.py
  # Test the filename 'libstdc++.so.6.*' has matched.
  test -f $LIBPATH/libstdc++.so.6.[0-9]*-gdb.py
done
test ! -e $RPM_BUILD_ROOT%{_datadir}/gdb/python/libstdcxx
cp -a $RPM_BUILD_DIR/%{gdb_src}/%{libstdcxxpython}/libstdcxx	\
      $RPM_BUILD_ROOT%{_datadir}/gdb/python/libstdcxx
for i in `find $RPM_BUILD_ROOT%{_datadir}/gdb/python -name "*.py"` \
         `find $RPM_BUILD_ROOT%{_datadir}/gdb/auto-load%{_prefix} -name "*.py"` \
; do
  # Files come from gdb-archer.patch and can be also further patched.
  touch -r $RPM_BUILD_DIR/%{gdb_src}/gdb/ChangeLog $i
done
%endif # 0%{!?_without_python:1}
%endif # 0%{?rhel:1} && 0%{?rhel} <= 6

# Remove the files that are part of a gdb build but that are owned and
# provided by other packages.
# These are part of binutils

rm -rf $RPM_BUILD_ROOT%{_datadir}/locale/
rm -f $RPM_BUILD_ROOT%{_infodir}/bfd*
rm -f $RPM_BUILD_ROOT%{_infodir}/standard*
rm -f $RPM_BUILD_ROOT%{_infodir}/configure*
rm -rf $RPM_BUILD_ROOT%{_includedir}
rm -rf $RPM_BUILD_ROOT/%{_libdir}/lib{bfd*,opcodes*,iberty*}

# pstack obsoletion

cp -p %{SOURCE3} $RPM_BUILD_ROOT%{_mandir}/man1/gstack.1
%endif	# 0%{!?_with_upstream:1}

# Packaged GDB is not a cross-target one.
(cd $RPM_BUILD_ROOT%{_datadir}/gdb/syscalls
 rm -f mips*.xml
%ifnarch sparc sparcv9 sparc64
 rm -f sparc*.xml
%endif
%ifnarch x86_64
 rm -f amd64-linux.xml
%endif
%ifnarch %{ix86} x86_64
 rm -f i386-linux.xml
%endif
%ifnarch ppc ppc64
 rm -f ppc{,64}-linux.xml
%endif
%ifnarch ppc64le
 rm -f ppc64le-linux.xml
%endif
)

# It would break RHEL-5 by leaving excessive files for the doc subpackage.
%if 0%{?el5:1}
rm -f $RPM_BUILD_ROOT%{_infodir}/annotate.info*
rm -f $RPM_BUILD_ROOT%{_infodir}/gdb.info*
%endif # 0%{?el5:1} 
# -j1: There is some race resulting in:
# /usr/bin/texi2dvi: texinfo.tex appears to be broken, quitting.
make -j1 -C gdb/doc install DESTDIR=$RPM_BUILD_ROOT

# Documentation only for development; keep 'rm's here after "noarch" above.
rm -f $RPM_BUILD_ROOT%{_infodir}/gdbint*
rm -f $RPM_BUILD_ROOT%{_infodir}/stabs*

# Delete this too because the dir file will be updated at rpm install time.
# We don't want a gdb specific one overwriting the system wide one.

rm -f $RPM_BUILD_ROOT%{_infodir}/dir

%post
# This step is part of the installation of the RPM. Not to be confused
# with the 'make install ' of the build (rpmbuild) process.

# For --excludedocs:
if [ -e %{_infodir}/gdb.info.gz ]
then
  %install_info --info-dir=%{_infodir} %{_infodir}/annotate.info.gz
  %install_info --info-dir=%{_infodir} %{_infodir}/gdb.info.gz
fi

%preun
if [ $1 = 0 ]
then
  # For --excludedocs:
  if [ -e %{_infodir}/gdb.info.gz ]
  then
    %install_info_delete --delete --info-dir=%{_infodir} %{_infodir}/annotate.info.gz
    %install_info_delete --delete --info-dir=%{_infodir} %{_infodir}/gdb.info.gz
  fi
fi

%files
%defattr(-,root,root)
%doc README NEWS
%if 0%{suse_version} >= 1320
%license COPYING3 COPYING COPYING.LIB
%else
%doc COPYING3 COPYING COPYING.LIB
%endif
%{_bindir}/gcore
%{_mandir}/*/gcore.1*
%{_bindir}/gdb
%config(noreplace) %{_sysconfdir}/gdbinit
%{_sysconfdir}/gdbinit.d
%{_mandir}/*/gdb.1*
%{_bindir}/gstack
%{_mandir}/*/gstack.1*
# Provide gdbtui for RHEL-5 and RHEL-6 as it is removed upstream (BZ 797664).
%if 0%{?rhel:1} && 0%{?rhel} <= 6
%{_bindir}/gdbtui
%{_mandir}/*/gdbtui.1*
%endif # 0%{?rhel:1} && 0%{?rhel} <= 6
%{_bindir}/gdb-add-index
%{_mandir}/*/gdb-add-index.1*
%{_mandir}/*/gdbinit.5*
%{_datadir}/gdb
%{_infodir}/annotate.info*
%{_infodir}/gdb.info*
# In SLE10 gdbserver is not in a separate package
%if %{suse_version} <= 1010
%{_bindir}/gdbserver
%{_mandir}/*/gdbserver.1*
%ifnarch s390 s390x ia64 ppc %{sparc}
%{_libdir}/libinproctrace.so
%endif
%endif

%if %{with testsuite}
%files testresults
%defattr(-,root,root)
%doc %{gdb_build}/gdb/gdb-*.sum
%doc %{gdb_build}/gdb/gdb-*.log
%endif

# don't include the files in include, they are part of binutils

%if %{suse_version} > 1010
%ifnarch sparcv9 hppa
%files -n gdbserver
%defattr(-,root,root)
%{_bindir}/gdbserver
%{_mandir}/*/gdbserver.1*
%if %{have_inproctrace}
%{_libdir}/libinproctrace.so
%endif # %{have_inproctrace}
%endif
%endif

%post doc
# This step is part of the installation of the RPM. Not to be confused
# with the 'make install ' of the build (rpmbuild) process.

# For --excludedocs:
if [ -e %{_infodir}/gdb.info.gz ]
then
  /sbin/install-info --info-dir=%{_infodir} %{_infodir}/annotate.info.gz || :
  /sbin/install-info --info-dir=%{_infodir} %{_infodir}/gdb.info.gz || :
fi

%preun doc
if [ $1 = 0 ]
then
  # For --excludedocs:
  if [ -e %{_infodir}/gdb.info.gz ]
  then
    /sbin/install-info --delete --info-dir=%{_infodir} %{_infodir}/annotate.info.gz || :
    /sbin/install-info --delete --info-dir=%{_infodir} %{_infodir}/gdb.info.gz || :
  fi
fi

%changelog
* Wed Nov  7 2018 tdevries@suse.com
- Fix crash when reading core [bsc #1109013]
  * Add gdb-fix-crash-when-reading-core.patch
    https://sourceware.org/ml/gdb-cvs/2018-11/msg00022.html
* Tue Sep 11 2018 matz@suse.com
- Rebase to 8.2 release (as in fedora 29 @ c720d998):
  * 'symbol-file' and 'add-symbol-file' accept -o to add relative
    offset to all sections
  * pager accepts 'c' response to disable it for rest of command
  * accept _Alignof and alignof in C resp. C++ expressions
  * new target riscv*-*-elf
  * python API extensions: gdb.Type.align, gdb.execute deals
    with multi-line gdb commands, gdb.convenience_variable and
    gdb.set_convenience_variable to access convenience variables,
  * aarch64: properly support hardware watchpoints on unaligned
    addresses (needs kernel >= 4.10)
- Add gdb-fix-s390-build.diff for a Wformat error on s390.
- Support access to new POWER8 registers [fate#325178, fate#326120]
  Add patches gdb-rhbz1187581-power8-regs-1of7.patch,
  gdb-rhbz1187581-power8-regs-2of7.patch,
  gdb-rhbz1187581-power8-regs-3of7.patch,
  gdb-rhbz1187581-power8-regs-4of7.patch,
  gdb-rhbz1187581-power8-regs-5of7.patch,
  gdb-rhbz1187581-power8-regs-6of7.patch,
  gdb-rhbz1187581-power8-regs-7of7.patch .
- Support ipv6 for gdbserver connections:
  Add patches gdb-rhbz881849-ipv6-1of3.patch,
  gdb-rhbz881849-ipv6-2of3.patch,
  gdb-rhbz881849-ipv6-3of3.patch .
- Update to intel processor trace library 2.0 (from 1.6.1):
  Add v2.0.tar.gz, remove v1.6.1.tar.gz
  Remove obsolete v1.6.1-implicit-fallthrough.patch .
- Remove obsolete patches:
  gdb-fix-python37-breakage.patch,
  gdb-pahole-python2.patch .
- Added patches from Fedora:
  gdb-rhbz1491128-batch-mode-exit-status-1of2.patch,
  gdb-rhbz1491128-batch-mode-exit-status-2of2.patch,
  gdb-rhbz1553104-s390x-arch12-test.patch,
  gdb-use-pulongest-aarch64-linux-tdep.patch .
- Removed obsolete patches from Fedora:
  gdb-6.6-bz235197-fork-detach-info.patch,
  gdb-6.8-attach-signalled-detach-stopped.patch,
  gdb-gdb-add-index-script.patch,
  gdb-ppc64-stwux-tautological-compare.patch,
  gdb-rhbz1540559-gdbaddindex-glibcdebug-regression.patch,
  gdb-stale-frame_info.patch .
- Most other patches rebased.
* Fri Aug 10 2018 tchvatal@suse.com
- Apply patch from fedora to build with python3.7:
  * gdb-fix-python37-breakage.patch
* Tue Mar 27 2018 matz@suse.com
- Add some -Wno-error flags for gcc-8 compatibility.
* Fri Mar  9 2018 matz@suse.com
- Rebase to 8.1 release:
  * ptype/o prints offsets and sizes of members (like pahole)
  * tab-completion improved: quoting function names is not generally
    necessary anymore, completion offers for breakpoint don't include
    data symbol
  * enable/disable breakpoints now accept ranges: 'disable 1.3-5'
  * new commands:
  - set/show cwd: working directory of debuggee
  - set/show compile-gcc: program to use for 'compile' command
  - starti: start program and stop at first instruction
  - TUI single-key commands: 'i' for stepi and 'o' for nexti
  * --readnever option disables any reading of debug info (for dumping)
  * s390: guarded storage register access for z14
  * gcore option -a dumps all memory mapping
  * C++ breakpoints: 'b foo' will now set a breakpoint on all functions
    and methods named 'foo' no matter the scope.  Use -qualified if you
    don't want that
  * python scripting: new events gdb.new_inferior, gdb.inferior_deleted
    and gdb.new_thread; new command rbreak (breakpoint accepting regexps)
  * gdbserver can be passed environment parameters to remote debuggee
- Added patches from Fedora:
  gdb-ppc64-stwux-tautological-compare.patch
  gdb-rhbz1540559-gdbaddindex-glibcdebug-regression.patch
  gdb-vla-intel-fix-print-char-array.patch
- Removed unused gdb-libstdc++-v3-python-7.1.1-20170526.tar.bz2
- Removed obsolete upstream patches:
  gdb-s390x-1b63490.patch
  gdb-s390x-289e23a.patch
  gdb-s390x-8fe09d7.patch
  gdb-s390x-96235dc.patch
  gdb-s390x-ad33963.patch
- Removed obsolete Fedora patches:
  gdb-6.3-rh-dummykfail-20041202.patch
  gdb-6.6-threads-static-test.patch
  gdb-add-index-chmod.patch
  gdb-glibc-vdso-workaround.patch
  gdb-rhbz1420304-s390x-01of35.patch
  gdb-rhbz1420304-s390x-02of35.patch
  gdb-rhbz1420304-s390x-03of35.patch
  gdb-rhbz1420304-s390x-04of35.patch
  gdb-rhbz1420304-s390x-05of35.patch
  gdb-rhbz1420304-s390x-06of35.patch
  gdb-rhbz1420304-s390x-07of35.patch
  gdb-rhbz1420304-s390x-08of35.patch
  gdb-rhbz1420304-s390x-09of35.patch
  gdb-rhbz1420304-s390x-10of35.patch
  gdb-rhbz1420304-s390x-11of35.patch
  gdb-rhbz1420304-s390x-12of35.patch
  gdb-rhbz1420304-s390x-13of35.patch
  gdb-rhbz1420304-s390x-14of35.patch
  gdb-rhbz1420304-s390x-15of35.patch
  gdb-rhbz1420304-s390x-16of35.patch
  gdb-rhbz1420304-s390x-17of35.patch
  gdb-rhbz1420304-s390x-18of35.patch
  gdb-rhbz1420304-s390x-19of35.patch
  gdb-rhbz1420304-s390x-20of35.patch
  gdb-rhbz1420304-s390x-21of35.patch
  gdb-rhbz1420304-s390x-22of35.patch
  gdb-rhbz1420304-s390x-23of35.patch
  gdb-rhbz1420304-s390x-24of35.patch
  gdb-rhbz1420304-s390x-25of35.patch
  gdb-rhbz1420304-s390x-26of35.patch
  gdb-rhbz1420304-s390x-27of35.patch
  gdb-rhbz1420304-s390x-28of35.patch
  gdb-rhbz1420304-s390x-29of35.patch
  gdb-rhbz1420304-s390x-30of35.patch
  gdb-rhbz1420304-s390x-31of35.patch
  gdb-rhbz1420304-s390x-32of35.patch
  gdb-rhbz1420304-s390x-33of35.patch
  gdb-rhbz1420304-s390x-34of35.patch
  gdb-rhbz1420304-s390x-35of35.patch
  gdb-tls-1of2.patch
  gdb-tls-2of2.patch
  gdb-upstream.patch
* Wed Nov 15 2017 schwab@suse.de
- Support --without=testsuite and disable testsuite for qemu-linux-user
  builds
* Wed Oct 25 2017 jmatejek@suse.com
- switch to Python 3 for Tumbleweed 1320 and up
* Mon Oct  9 2017 matz@suse.com
- Remove %%clean section.
* Wed Oct  4 2017 matz@suse.com
- Link gdb against a bundled libipt (processor trace
  library) on x86_64 and i686 for improved tracing support
  on Intel CPUs.  [bnc#985550]
  Adds v1.6.1.tar.gz and patches
  v1.5-libipt-static.patch and v1.6.1-implicit-fallthrough.patch.
* Mon Oct  2 2017 matz@suse.com
- Rebase to 8.0.1 release (fixing PR21886, PR22046)
- Updated libstdc++ pretty printers to
- Replace gdb-libstdc++-v3-python-6.3.1-20170212.tar.bz2 with
  gdb-libstdc++-v3-python-7.1.1-20170526.tar.bz2 .
- Add patches for s390x z14 feates [fate #321514, fate #322272]
  gdb-s390x-1b63490.patch
  gdb-s390x-289e23a.patch
  gdb-s390x-8fe09d7.patch
  gdb-s390x-96235dc.patch
  gdb-s390x-ad33963.patch
- Adjust some patches:
  gdb-ppc-power7-test.patch
  gdb-rhbz795424-bitpos-20of25.patch
  gdb-rhbz795424-bitpos-21of25.patch
  gdb-vla-intel-fortran-vla-strings.patch
- Add some patches from Fedora:
  gdb-rhbz1420304-s390x-01of35.patch
  gdb-rhbz1420304-s390x-02of35.patch
  gdb-rhbz1420304-s390x-03of35.patch
  gdb-rhbz1420304-s390x-04of35.patch
  gdb-rhbz1420304-s390x-05of35.patch
  gdb-rhbz1420304-s390x-06of35.patch
  gdb-rhbz1420304-s390x-07of35.patch
  gdb-rhbz1420304-s390x-08of35.patch
  gdb-rhbz1420304-s390x-09of35.patch
  gdb-rhbz1420304-s390x-10of35.patch
  gdb-rhbz1420304-s390x-11of35.patch
  gdb-rhbz1420304-s390x-12of35.patch
  gdb-rhbz1420304-s390x-13of35.patch
  gdb-rhbz1420304-s390x-14of35.patch
  gdb-rhbz1420304-s390x-15of35.patch
  gdb-rhbz1420304-s390x-16of35.patch
  gdb-rhbz1420304-s390x-17of35.patch
  gdb-rhbz1420304-s390x-18of35.patch
  gdb-rhbz1420304-s390x-19of35.patch
  gdb-rhbz1420304-s390x-20of35.patch
  gdb-rhbz1420304-s390x-21of35.patch
  gdb-rhbz1420304-s390x-22of35.patch
  gdb-rhbz1420304-s390x-23of35.patch
  gdb-rhbz1420304-s390x-24of35.patch
  gdb-rhbz1420304-s390x-25of35.patch
  gdb-rhbz1420304-s390x-26of35.patch
  gdb-rhbz1420304-s390x-27of35.patch
  gdb-rhbz1420304-s390x-28of35.patch
  gdb-rhbz1420304-s390x-29of35.patch
  gdb-rhbz1420304-s390x-30of35.patch
  gdb-rhbz1420304-s390x-31of35.patch
  gdb-rhbz1420304-s390x-32of35.patch
  gdb-rhbz1420304-s390x-33of35.patch
  gdb-rhbz1420304-s390x-34of35.patch
  gdb-rhbz1420304-s390x-35of35.patch
  gdb-upstream.patch
* Wed Sep 13 2017 matz@suse.com
- Disable guile extensions for new distros, the gdb support
  is incompatible with guile 2.2.
* Tue Jun  6 2017 matz@suse.com
- Rebase to gdb 8.0 release: [fate #319573]
  * support for DWARF5 (except its .debug_names)
  * support C++11 rvalue references
  * support PKU register (memory protection keys on future Intel CPUs)
  * python scripting:
  - start, stop and access running btrace
  - rvalue references in gdb.Type
  * record/replay x86_64 rdrand and rdseed
  * removed support for GCJ compiled java programs
  * user commands accept more than 10 arguments
  * "eval" expands user-defined command arguments
  * new options:
    set/show disassembler-options (on arm, ppc s390)
- Removed obsoleted patches:
  gdb-release-werror.patch
* Thu Apr 27 2017 matz@suse.com
- Rebase to gdb 7.99.90 (prerelease of gdb 8) [fate #319573]
- Updated libstdc++ pretty printers to
  gdb-libstdc++-v3-python-6.3.1-20170212.tar.bz2.
- Added patches from fedora:
  gdb-release-werror.patch
  gdb-rhbz1398387-tab-crash-test.patch
- Removed obsoleted patches:
  gdb-6.7-bz426600-DW_TAG_interface_type-test.patch
  gdb-bison-old.patch
  gdb-testsuite-casts.patch
  gdb-testsuite-m-static.patch
  gdb-upstream.patch
  gdb-testsuite-morestack-gold.patch
  gdb-fix-bnc-994537.diff
  gdb-libiberty-demangler-fuzz.diff
* Mon Apr  3 2017 rguenther@suse.com
- Fix rpm condition to allow build on SLE10.
- Do not require glibc-devel-static-32bit on SLE12 which is not available
  there.
* Wed Feb 15 2017 matz@suse.com
- Update to gdb 7.12.1
  * negative repeat count for x examines backwards
  * fortran: support structs/arrays with dynamically types fields
  * support MPX bound checking
  * support for the Rust language
  * 'catch syscall' now can catch groups of related syscalls
  * New (sub)commands:
  - skip {-file,-gfile,-function,-rfunction}: generic skip
    mechanism
  - maint {selftest,info line-table}
  - new-ui: create new user interface for GUI clients
  * (fast) tracepoints on s390x and ppc64le added to gdbserver
  * New target Andes NDS32
- Add rpmlint exception for historic libinproctrace place
- Remove obsolete patches:
  gdb-aarch64-v81-hwbreakpoints.diff
  gdb-bare-DW_TAG_lexical_block-1of2.patch
  gdb-bare-DW_TAG_lexical_block-2of2.patch
  gdb-fortran-stride-intel-1of6.patch
  gdb-fortran-stride-intel-2of6.patch
  gdb-fortran-stride-intel-3of6.patch
  gdb-fortran-stride-intel-4of6.patch
  gdb-fortran-stride-intel-5of6.patch
  gdb-fortran-stride-intel-6of6-nokfail.patch
  gdb-fortran-stride-intel-6of6.patch
  gdb-testsuite-dw2-undefined-ret-addr.patch
  gdb-vla-intel-04of23-fix.patch
  gdb-vla-intel-logical-not.patch
  gdb-vla-intel.patch
- Add patches from Fedora package:
  gdb-6.7-testsuite-stable-results.patch
  gdb-add-index-chmod.patch
  gdb-bison-old.patch
  gdb-container-rh-pkg.patch
  gdb-libexec-add-index.patch
  gdb-linux_perf-bundle.patch
  gdb-physname-pr11734-test.patch
  gdb-physname-pr12273-test.patch
  gdb-rhbz1007614-memleak-infpy_read_memory-test.patch
  gdb-rhbz1084404-ppc64-s390x-wrong-prologue-skip-O2-g-3of3.patch
  gdb-rhbz1149205-catch-syscall-after-fork-test.patch
  gdb-rhbz1156192-recursive-dlopen-test.patch
  gdb-rhbz1186476-internal-error-unqualified-name-re-set-test.patch
  gdb-rhbz1350436-type-printers-error.patch
  gdb-test-ivy-bridge.patch
  gdb-testsuite-casts.patch
  gdb-testsuite-m-static.patch
  gdb-testsuite-morestack-gold.patch
  gdb-tls-1of2.patch
  gdb-tls-2of2.patch
  gdb-upstream.patch
  gdb-vla-intel-fortran-strides.patch
  gdb-vla-intel-fortran-vla-strings.patch
  gdb-vla-intel-tests.patch
* Mon Jan  9 2017 matz@suse.com
- Disable 32bit testing on openSUSE s390x.
* Fri Dec 16 2016 mliska@suse.cz
- Make dependency of gcc-java conditional.
* Sat Dec  3 2016 schwab@suse.de
- Enable ada testing on aarch64 for tumbleweed
* Mon Nov 21 2016 schwab@suse.de
- BuildRequire glibc-devel-static for 12.1 or later, and
  glibc-devel-static-32bit if biarch
* Thu Aug 25 2016 matz@suse.com
- Add gdb-fix-bnc-994537.diff for ppc64le, fixing
  two testcases.  [bnc#994537]
- Add gdb-libiberty-demangler-fuzz.diff for fixing infinite
  recursion in demangler.  [bnc#987637]
* Mon Aug  8 2016 matz@suse.com
- Amend gdb-glibc-vdso-workaround.patch to ignore further
  vdso filenames on ppc64 and s390x.  [bnc#944105]
* Wed Aug  3 2016 matz@suse.com
- Add gdb-aarch64-v81-hwbreakpoints.diff for detecting
  debug capabilities on ARMv8.1/8.2.  [bnc#990697]
* Mon Jun 20 2016 matz@suse.com
- Rebase to gdb 7.11.1: minor bug fixes.
- Remove gdb-gcc6-Wparentheses-warning.patch (applied upstream).
- Add some patches from Fedora F24:
  gdb-bare-DW_TAG_lexical_block-1of2.patch
  gdb-bare-DW_TAG_lexical_block-2of2.patch
  gdb-bz1219747-attach-kills.patch
  gdb-rhbz1261564-aarch64-hw-watchpoint-test.patch
  gdb-rhbz1325795-framefilters-test.patch
  gdb-testsuite-dw2-undefined-ret-addr.patch
* Tue May 24 2016 martin.liska@suse.com
- Add gdb-gcc6-Wparentheses-warning.patch to fix Werrors reported by GCC6.
* Mon Apr 25 2016 rguenther@suse.com
  [diverging changelog entry from SLE tree vs devel:gcc tree:
- Add gdb-7.9-bnc976404.patch to fix thread support on s390x. [bnc #976404]
  [bnc #970589]
- Add gdb-7.9-swo18929.patch to fix crash printing values.  [bnc#971556]
  ]
- Removed gdb-7.9-bnc976404.patch when updating to devel:gcc tree.
- Replaced gdb-7.9-swo18929.patch with gdb-7.10-swo18929.patch as well.
* Thu Apr  7 2016 normand@linux.vnet.ibm.com
-  update gdb-orphanripper.c from last fedora changes of 2013
  http://pkgs.fedoraproject.org/cgit/rpms/gdb.git/log/gdb-orphanripper.c
  may be solution to transient build hung on Rings:1 ppc64le
  tracked by bug boo#974419
* Mon Mar 21 2016 rguenther@suse.com
- Add gdb-7.10-swo18929.patch to fix crash printing values.  [bnc#971556]
  [swo#18929]
* Mon Feb 29 2016 matz@suse.de
- Rebase to gdb version 7.11 as of version in Fedora 24:
  * Per-inferior thread numbers.
  * Breakpoint "explicit locations" (via CLI and GDB/MI).
  * New convenience variables ($_gthread, $_inferior).
  * Record btrace now supports non-stop mode.
  * Various improvements on AArch64 GNU/Linux:
  - Multi-architecture debugging support.
  - displaced stepping.
  - tracepoint support added in GDBserver.
  * In Ada, the overloads selection menu provides the parameter
    types and return types for the matching overloaded subprograms.
  * Various remote protocol improvements, including several
    new packets which can be used to support features such as
    follow-exec-mode, exec catchpoints, syscall catchpoints, etc.
  * Some minor improvements in the Python API for extending GDB.
- Added local patch gdb-fix-buf-overflow.diff.
- Added new patches from Fedora:
    gdb-fedora-libncursesw.patch
    gdb-fortran-stride-intel-1of6.patch
    gdb-fortran-stride-intel-2of6.patch
    gdb-fortran-stride-intel-3of6.patch
    gdb-fortran-stride-intel-4of6.patch
    gdb-fortran-stride-intel-5of6.patch
    gdb-fortran-stride-intel-6of6-nokfail.patch
    gdb-fortran-stride-intel-6of6.patch
    gdb-opcodes-clflushopt-test.patch
    gdb-testsuite-readline63-sigint.patch
- Removed obsolete patches:
    gdb-6.3-bz231832-obstack-2gb.patch
    gdb-probes-based-interface-robust-1of2.patch
    gdb-probes-based-interface-robust-2of2.patch
    gdb-rhbz1260558-ppc64le-skip_trampoline_code.patch
    gdb-rhbz1270564-invalid-dwarf-regno.patch
    gdb-rhel5-compat.patch
- Really disable problematic testcases.
* Mon Jan 18 2016 matz@suse.de
- Disable guile support for SLE10.
* Thu Jan 14 2016 matz@suse.de
- Rebase to gdb version 7.10.1 as of version in Fedora 23:
  * reverse debugging on aarch64
  * new commands or subcommands:
  - info os cpu, set/show serial parity, info dll
  - maint print symbol-cache/symbol-cache-statistics,
    maint flush-symbol-cache
  - record btrace bts, record bts
  - compile print
  - show/set mpx bound
  - tui enable/disable
  - record btrace pt, record pt
  - maint info btrace,
    maint btrace packet-history/clear-packet-history/clear
  * s390 support for vector ABI
  * "set sysroot" improvements related to remote targets
  * better support for debugging containerized programs
    (without "set sysroot")
  * HISTSIZE environment variable is replaced by GDBHISTSIZE
  * python scripting:
  - it's possible to write frame unwinders
  - several new methods in Objfile, Type and Value classes
  - gdb can auto-load scripts contained in special sections
    named '.debug_gdb_scripts'.
  * extensions for the MI interface, new remote packet types
- Removed obsolete patches:
    0001-S390-Add-target-descriptions-for-vector-register-set.patch
    0001-S390-Fix-compiler-invocation-with-compile-command.patch
    0001-S390-Support-new-vector-register-sections.patch
    0002-S390-Add-vector-register-support-to-gdb.patch
    0003-S390-Add-vector-register-support-to-gdbserver.patch
    0004-S390-Vector-register-test-case.patch
    0005-S390-Name-invisible-registers-with-the-empty-string-.patch
    gdb-6.5-bz190810-gdbserver-arch-advice.patch
    gdb-6.6-scheduler_locking-step-sw-watchpoints2.patch
    gdb-6.8-bz457187-largefile-test.patch
    gdb-enable-count-crash.patch
    gdb-libstdc++-v3-python-r155978.tar.bz2
    gdb-no-dg-extract-results-py.patch
    gdb-python3-py_hash_t-32bit.patch
    gdb-python3-testsuite.patch
    gdb-s390-reorder-arch.diff
    gdb-upstream.patch
- Added new patches from Fedora:
    gdb-pahole-python2.patch
    gdb-probes-based-interface-robust-1of2.patch
    gdb-probes-based-interface-robust-2of2.patch
    gdb-rhbz1260558-ppc64le-skip_trampoline_code.patch
    gdb-rhbz1270564-invalid-dwarf-regno.patch
* Fri Aug 14 2015 matz@suse.de
- Add missing patches from binutils for z13 support. [bnc #936050]
* Fri Jul 10 2015 matz@suse.de
- Rebase to gdb version 7.9.1:
  fixes PR python/18299, python/18285.
- Add gdb-s390-reorder-arch.diff [bnc #936050]
- Added patches for fate#318039, s390 z13 support:
  0001-S390-Fix-compiler-invocation-with-compile-command.patch
  0001-S390-Support-new-vector-register-sections.patch
  0001-S390-Add-target-descriptions-for-vector-register-set.patch
  0002-S390-Add-vector-register-support-to-gdb.patch
  0003-S390-Add-vector-register-support-to-gdbserver.patch
  0004-S390-Vector-register-test-case.patch
  0005-S390-Name-invisible-registers-with-the-empty-string-.patch
- Remove now obsolete SLE12-only patches:
  gdb-7.7-bnc896586.patch, gdb-7.7-bnc895831.patch,
  gdb-7.7-bnc891040-1.patch, gdb-7.7-bnc891040-2.patch,
  gdb-7.7-bnc891040-3.patch, gdb-7.7-bnc891040-4.patch,
  gdb-7.7-bnc891040-5.patch
* Thu Jul  2 2015 rguenther@suse.com
- Remove auto-loading non-existent /etc/gdbinit.d/gdb-heap.py
  from /etc/gdbinit
* Mon Jun 29 2015 schwab@suse.de
- Add guile-devel to enable Scheme scripting support
- Run ada tests also on ppc64 and s390
* Tue Mar  3 2015 schwab@suse.de
- Build multi-target also on aarch64
* Fri Feb 27 2015 rguenther@suse.com
- Strip date and runtimes from gdb-testsuite contents.
* Wed Feb 25 2015 rguenther@suse.com
- Use patchlist.pl to merge with gdb-7.9-10.fc22, a rebase to FSF GDB 7.9.
  The GDB 7.8 features are:
  * Python Scripting
  - You can now access frame registers from Python scripts.
  - New attribute 'producer' for gdb.Symtab objects.
  * New Python-based convenience functions:
  - $_caller_is(name [, number_of_frames])
  - $_caller_matches(regexp [, number_of_frames])
  - $_any_caller_is(name [, number_of_frames])
  - $_any_caller_matches(regexp [, number_of_frames])
  * New commands
  - queue-signal signal-name-or-number
    Queue a signal to be delivered to the thread when it is resumed.
  * On resume, GDB now always passes the signal the program had stopped
    for to the thread the signal was sent to, even if the user changed
    threads before resuming.  Previously GDB would often (but not
    always) deliver the signal to the thread that happens to be current
    at resume time.
  * Conversely, the "signal" command now consistently delivers the
    requested signal to the current thread.  GDB now asks for
    confirmation if the program had stopped for a signal and the user
    switched threads meanwhile.
  * "breakpoint always-inserted" modes "off" and "auto" merged.
    Now, when 'breakpoint always-inserted mode' is set to "off", GDB
    won't remove breakpoints from the target until all threads stop,
    even in non-stop mode.  The "auto" mode has been removed, and "off"
    is now the default mode.
  * MI changes
  - The -list-thread-groups command outputs an exit-code field for
    inferiors that have exited.
- removed (upstream) gdb-async-stopped-on-pid-arg-1of2.patch,
  gdb-async-stopped-on-pid-arg-testsuite.patch,
  gdb-python-completer-1of2.patch, gdb-python-completer-2of2.patch
  and gdb-readline-6.3.5.patch
- added gdb-jit-reader-multilib.patch, gdb-no-dg-extract-results-py.patch,
  gdb-python-gil.patch, gdb-python3-py_hash_t-32bit.patch,
  gdb-python3-testsuite.patch and gdb-vla-intel-logical-not.patch
* Mon Dec 15 2014 cshorler@googlemail.com
- Update for GDB 7.8.1
  * removed (already in upstream):
    gdb-babeltrace-configure.patch
    gdb-async-stopped-on-pid-arg-2of2.patch
  * amended (partially in upstream):
    gdb-archer.patch
    gdb-attach-fail-reasons-5of5.patch
    gdb-async-stopped-on-pid-arg-1of2.patch
    gdb-async-stopped-on-pid-arg-testsuite.patch
* Fri Oct 10 2014 hrvoje.senjan@gmail.com
- Added gdb-async-stopped-on-pid-arg-1of2.patch,
  gdb-async-stopped-on-pid-arg-2of2.patch and
  gdb-async-stopped-on-pid-arg-testsuite.patch to resolve
  https://sourceware.org/bugzilla/show_bug.cgi?id=17347
* Wed Aug 13 2014 rguenther@suse.com
- Enable running the testsuite and store results in a gdb-testresults
  package.
- Add gdb-rpmlintrc to filter errors about the buildroot mentioned
  in testresult logs.
* Fri Aug  8 2014 rguenther@suse.com
- Use patchlist.pl to merge with gdb-7.8-16.fc22, a rebase to FSF GDB 7.8.
  The GDB 7.8 features are:
  * Guile scripting support.
  * Python scripting enhancements.
  * New commands:
  * * guile
  * * guile-repl
  * * info auto-load guile-scripts [REGEXP]
  * New options:
  * * maint ada set ignore-descriptive-types (on|off)
  * * maint set target-async (on|off)
  * * set|show auto-load guile-scripts (on|off)
  * * set|show auto-connect-native-target
  * * set|show guile print-stack (none|message|full)
  * * set|show mi-async (on|off)
  * * set|show print symbol-loading (off|brief|full)
  * * set|show record btrace replay-memory-access (read-only|read-write)
  * Remote Protocol:
  * * The qXfer:btrace:read packet supports a new annex 'delta'.
  * GDB/MI:
  * * A new option "-gdb-set mi-async" replaces "-gdb-set target-async".
  * New target configurations:
  * * PowerPC64 GNU/Linux little-endian
  * btrace enhancements:
  * * The btrace record target now supports the 'record goto' command.
  * * The btrace record target supports limited reverse execution and
    replay.
  * ISO C99 variable length automatic arrays support.
  * It is no longer required to "set target-async on" in order to use
    background execution commands (e.g., "c&", "s&", etc.).
  * "catch syscall" now implemented on s390*-linux* targets.
  * The "compare-sections" command now works on all targets.
  * The "target native" command now connects to the native target, and
    can be used to launch native programs, even if "set
    auto-connect-native-target" is set to off.
  * More robust backtraces.  [bnc#891040]
- Obsoletes patch gdb-7.7-bnc877566.patch
- Obsoletes patch gdb-fix-s390-build.patch
- Obsoletes patch gdb-ppc64le.patch
- Drop gdb-ia64-tdep.patch, disable building the IA64 target
- Modifies gdb-6.3-test-pie-20050107.patch,
  gdb-6.5-bz218379-solib-trampoline-lookup-lock-fix.patch,
  gdb-6.6-buildid-locate-core-as-arg.patch,
  gdb-6.6-buildid-locate-rpm.patch, gdb-6.6-buildid-locate.patch,
  gdb-6.6-scheduler_locking-step-is-default.patch,
  gdb-6.6-scheduler_locking-step-sw-watchpoints2.patch,
  gdb-6.8-attach-signalled-detach-stopped.patch,
  gdb-6.8-quit-never-aborts.patch,
  gdb-archer-pie-addons-keep-disabled.patch, gdb-archer-pie-addons.patch,
  gdb-archer.patch, gdb-attach-fail-reasons-5of5.patch,
  gdb-glibc-strstr-workaround.patch, gdb-rhbz795424-bitpos-20of25.patch,
  gdb-rhbz795424-bitpos-21of25.patch, gdb-rhbz795424-bitpos-22of25.patch,
  gdb-rhbz795424-bitpos-23of25.patch, gdb-rhbz795424-bitpos-25of25.patch,
  gdb-upstream.patch
- Adds gdb-archer-vla-tests.patch, gdb-bz533176-fortran-omp-step.patch,
  gdb-bz541866-rwatch-before-run.patch
  gdb-6.6-buildid-locate-misleading-warning-missing-debuginfo-rhbz981154.patch,
  gdb-babeltrace-configure.patch, gdb-btrobust.patch,
  gdb-dts-rhel6-python-compat.patch, gdb-fortran-frame-string.patch,
  gdb-gnat-dwarf-crash-3of3.patch, gdb-python-completer-1of2.patch,
  gdb-python-completer-2of2.patch, gdb-readline-6.3.5.patch,
  gdb-vla-intel-04of23-fix.patch, gdb-vla-intel-stringbt-fix.patch,
  gdb-vla-intel.patch
- Removes gdb-rhel5-gcc44.patch, gdb-6.6-bfd-vdso8k.patch,
  gdb-testsuite-nohostid.patch, gdb-python-stacksmash.patch
* Tue Jul 15 2014 rguenther@suse.com
  (was: Mon Sep 15 07:42:50 UTC 2014 - rguenther@suse.com)
- Backport fix for gdb internal-error on register info on PPC64LE.
  Addds patch gdb-7.7-bnc896586.patch.  [bnc#896586]
* Thu Jul 10 2014 rguenther@suse.com
  (was: Wed Sep 10 07:41:20 UTC 2014 - rguenther@suse.com)
- Backport fix for gdbserver PPC64LE byteorder issue.  [bnc#895831]
  Adds patch gdb-7.7-bnc895831.patch.
* Tue Jul  8 2014 rguenther@suse.com
  (was: Tue Aug 12 08:13:11 UTC 2014 - rguenther@suse.com)
- Backport all frame-related changes from gdb 7.8.  Adds patches
  gdb-7.7-bnc891040-1.patch, gdb-7.7-bnc891040-2.patch,
  gdb-7.7-bnc891040-3.patch, gdb-7.7-bnc891040-4.patch,
  gdb-7.7-bnc891040-5.patch  [bnc#891040]
* Thu Jun 26 2014 rguenther@suse.com
- Add baselibs.conf to sources.
* Thu Jun 26 2014 rguenther@suse.com
- For _with_testsuite require gcc-fortran, not gcc-gfortran.
  [bnc#884399]
* Wed May 14 2014 rguenther@suse.com
- Fix debugging of threaded 31bit inferiors on s390x
  (gdb-7.7-bnc877566.patch).  [bnc#877566]
- Add patchlist.pl and patchname_get.sh as sources.
* Wed Feb 12 2014 matz@suse.de
- Fix build on s390 (gdb-fix-s390-build.patch).
* Mon Feb 10 2014 matz@suse.de
- Use patchlist.pl to merge with gdb-Fedora at
  e86a0cc13a5d91ba95242690237bb77511500897.
- Don't apply patches gdb-rhel5-gcc44.patch,
  gdb-6.6-buildid-locate-rpm-scl.patch,
  gdb-readline62-ask-more-rh.patch,
  gdb-6.8-attach-signalled-detach-stopped.patch,
  gdb-6.8-quit-never-aborts.patch,
  gdb-rhel5-compat.patch; retained to have same structure as fedoras
  package.
- Add gdb-testsuite-nohostid.patch (from fedora).
- Remove gdb-fix-attach-signalled-detach-stopped.patch again
  (as base not applied), gdb-ppc-ptrace.diff (not applied since some time).
* Sun Feb  9 2014 burnus@net-b.de
- Merge from fedoras gdb-7.7-1.fc21, a rebase to FSF GDB 7.7.
  The 7.7 features are:
  * For C++, the 'typeid' operator has been added and
    exception catchpoints can be filtered by type.
  * Python scripting has been extended
  * New commands and new command options
  * New convenice variables/functions
  * Some GDB/MI improvements
  * Remote protocal improvments
  * SystemTap SDT probes support AArch64 GNU/Linux
  * Support for Fission DWP file format version 2
  * 'tsave' command supports CTF (Common Trace Format)
  * New script 'gcore'
- Remove now obsolete gdb-aarch64-hw-break.patch
- Remove merged bits from gdb-ppc64le.patch
- Rediff gdb-6.6-buildid-locate-rpm-suse.patch
- Add gdb-fix-attach-signalled-detach-stopped.patch
* Mon Dec  9 2013 uweigand@de.ibm.com
- gdb-ppc64le.patch: add support for powerpc64le-linux
* Fri Nov 15 2013 rguenther@suse.com
- Allow librpm3 to be used
* Thu Sep 12 2013 schwab@suse.de
- gdb-aarch64-hw-break.patch: apply last change also to gdbserver
* Mon Aug 12 2013 schwab@suse.de
- gdb-aarch64-hw-break.patch: fix setting hardware debug registers after
  fork
* Wed Aug  7 2013 matz@suse.com
- Merge from fedoras gdb-7.6.50-20130731-cvs, of what will become 7.7
  eventually.  This includes 7.6, which gave:
  * new native configurations (e.g. ARM AArch64 GNU/Linux)
  * new targets (e.g. ARM AArch64, Lynx 178 PowerPC, x86_64/Cygwin)
  * support for the "mini debuginfo" section, .gnu_debugdata
  * the C++ ABI now defaults to the GNU v3 ABI
  * more Python scripting improvements
  * some GDB/MI improvements
  * new configure options, new commands, and options
  * new remote packets
  * a new "target record-btrace" has been added while the
    "target record" command has been renamed to "target record-full"
- gdb-ia64-tdep.patch: build fixes
- gdb-ppc-ptrace.diff: Remove patch, not needed on new kernels
* Tue Jul  2 2013 schwab@suse.de
- Enable multi-target support
- gdb-ia64-tdep.patch: build fixes
- Use --build when configuring
- Don't remove %%buildroot in %%install
- Set pkgversion and bugurl
* Sun Mar 17 2013 matz@suse.com
- Update to 7.5.50, mostly for aarch64.
* Mon Dec  3 2012 matz@suse.com
- Merge from gdb-7.5.1-30.fc18.src.rpm.
  7.5.1 gives:
  * An "Attempt to dereference a generic pointer" errors (-var-create).
  * Backtrace problems on x32 (PR backtrace/14646).
  * next/step/finish problems on x32 (PR gdb/14647).
  * A "malformed linespec error: unexpected keyword, [...]" error
    (PR breakpoints/14643).
  * GDB crash while stepping through powerpc (32bits) code.
  * A failed assertion in linux_ptrace_test_ret_to_nx.
  * A "!frame_id_inlined_p (frame_id)" failed assertion.
  * A "No more reverse-execution history." error during reverse
    "next" execution (PR 14548).
  * Incomplete command descriptions in "apropos" output.
  * PR gdb/14494 (a GDB crash difficult to characterize).
  7.5 gives:
  * Go language support.
  * New targets (x32 ABI, microMIPS, Renesas RL78, HP OpenVMS ia64).
  * More Python scripting improvements.
  * SDT (Static Defined Tracing) probes support with SystemTap probes.
  * GDBserver improvements (stdio connections, target-side evaluation
    of breakpoint conditions, remote protocol improvements).
  * Other miscellaneous improvements (ability to stop when a shared
    library is loaded/unloaded, dynamic printf, etc).
  * Reverse debugging on ARM.
* Tue Jun 19 2012 rguenther@suse.com
- Do not provide a custom (safe) auto-load dir.
* Tue Jun 12 2012 rguenther@suse.com
- Merge from gdb-7.4.50.20120603-3.fc18.src.rpm.
  * Wed Jun  6 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120603-3.fc18
  - Disable -lmcheck in the development builds.
  - Fix assertion on some files as glibc-2.15.90-8.fc18 (Doug Evans).
  * Sun Jun  3 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120603-2.fc18
  - Fix Release.
  - Make yum --enablerepo compatible with at least mock-1.1.21-1.fc16 Rawhide cfg.
  * Sun Jun  3 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120602-1.fc18
  - Rebase to FSF GDB 7.4.50.20120602.
  - [testsuite] BuildRequire gcc-go.
  - Drop printing 2D C++ vectors as matrices which no longer worked (BZ 562763).
  - Fix dejagnu-1.5-4.fc17 compatibility for Go (for BZ 635651).
  - Use librpm.so.3 for rpm-4.10.0 in Fedora 18.
  - Revert recent breakage of UNIX objfiles order for symbols lookup.
  * Sat Jun  2 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-48.fc17
  - [ppc] Fix hardware watchpoints on PowerPC (BZ 827600, Edjunior Machado).
  * Mon May 28 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-47.fc17
  - Workaround PR libc/14166 for inferior calls of strstr.
  * Mon May 14 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-46.fc17
  - [RHEL5] Workaround doc build race.
  * Mon May 14 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-45.fc17
  - Rename "set auto-load" patchset variable $ddir to $datadir.
  * Wed May  9 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-44.fc17
  - Fix in "set auto-load" patchset for SCL scripts inheritance (BZ 815910).
  * Wed Apr 25 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-43.fc17
  - [RHEL5] Workaround kernel for detaching SIGSTOPped processes (BZ 809382).
  * Tue Apr 24 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-42.fc17
  - Update "set auto-load" patchset and the --with-auto-load-safe-path setting.
  - [RHEL] Disable gdb-add-index even on RHEL-6 as RHEL-6.0 had too old elfutils.
  * Wed Apr 18 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-41.fc17
  - [RHEL] Fix --with-auto-load-safe-path systems prior to /usr move.
  * Wed Apr 18 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-40.fc17
  - Security fix for loading untrusted inferiors, see "set auto-load" (BZ 756117).
  * Fri Apr 13 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-39.fc17
  - [RHEL7] Fix/remove readline-devel BuildRequires redundant distro suffic .fc17.
  * Wed Apr  4 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-38.fc17
  - Workaround crashes from stale frame_info pointer (BZ 804256).
  * Wed Apr  4 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-37.fc17
  - testsuite: Fix break-interp.exp expections for updated glibc (BZ 752834).
  * Wed Apr  4 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-36.fc17
  - [RHEL5,RHEL6] Reintroduce fix attaching to stopped processes.
  * Fri Mar 30 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-35.fc17
  - Fix performance regressions with .gdb_index (Tom Tromey, BZ 805274).
  * Fri Mar 30 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-34.fc17
  - Fixup %%{_datadir}/gdb timestamps for multilib conflicts on RHELs.
  * Mon Mar 26 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-33.fc17
  - [vla] Fix regression on no type for subrange from IBM XLF Fortran (BZ 806920).
  * Sat Mar 17 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-32.fc17
  - Fix loading of core files without build-ids but with build-ids in executables.
  * Fri Mar  9 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-31.fc17
  - Fix an implied regression by the inferior calls fix below (BZ 799531).
  * Fri Mar  9 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-30.fc17
  - Fix SELinux deny_ptrace .spec build rules (BZ 786878).
  * Tue Mar  6 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-29.fc17
  - Fix inferior calls, particularly uncaught thrown exceptions (BZ 799531).
  - Fix DWARF DIEs CU vs. section relative offsets (Joel Brobecker, me).
  * Tue Mar  6 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-28.fc17
  - Print reasons for failed attach/spawn incl. SELinux deny_ptrace (BZ 786878).
  * Sun Mar  4 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-27.fc17
  - [rhel5] Fix up the previous commit (BZ 799318).
  * Sun Mar  4 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-26.fc17
  - [rhel5] Fix up the previous commit (BZ 799318).
  * Sun Mar  4 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-25.fc17
  - [rhel5] Workaround rpmbuild to make the doc subpkg noarch again (BZ 799318).
  * Fri Mar  2 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-24.fc17
  - [vla] Fix crash for dynamic.exp with gcc-gfortran-4.1.2-51.el5.x86_64.
  - Reintroduce RHEL-5 glibc workaround for bt-clone-stop.exp.
  - testsuite: Update/fix rh634108-solib_address.exp for the upstreamed API.
  * Wed Feb 29 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-23.fc17
  - Add kernel vDSO workaround (`no loadable ...') on RHEL-5 (kernel BZ 765875).
  - Fix skipping of prologues on RHEL-5 gcc-4.1 -O2 -g code (BZ 797889).
  - Fix breakpoint warning during 'next' over exit() (Tom Tromey, BZ 797892).
  * Tue Feb 28 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-22.fc17
  - testsuite: Fix gdb.base/macscp.exp ccache workaround in SCL mode.
  - Adjust the RHEL/F version string automatically (BZ 797651, BZ 797646).
  - Provide gdbtui for RHEL-5 and RHEL-6 as it is removed upstream (BZ 797664).
  * Fri Feb 24 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-21.fc17
  - testsuite: Do not use gcc44/gfortran44 on RHEL-5 if in SCL mode.
  * Wed Feb 22 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-20.fc17
  - Fix libinproctrace.so build on RHEL-5 i386 (disable it on RHEL-5).
  * Wed Feb 22 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-19.fc17
  - Implement SCL (scl-utils-build) macros.
  * Tue Feb 21 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-18.fc17
  - Fix debuginfo gdb-gdb.py build without redhat-rpm-config and on RHEL-5.
  - Provide precompiled variants of gdb-gdb.py.
  * Mon Feb 13 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-17.fc17
  - gstack: Turn off --readnever (suggested by Oliver Henshaw).
  * Fri Feb 10 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-16.fc17
  - [RHELs] Drop simulation of legacy behavior - new GDB should behave as new GDB.
  * Fri Feb 10 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-15.fc17
  - Simplify %%%%setup .spec rule.
  * Fri Feb 10 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-14.fc17
  - Drop --with upstream .spec rules.
  * Fri Feb 10 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-13.fc17
  - Drop --with debug .spec rules.
  * Thu Feb  9 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-12.fc17
  - Improve performance for C++ symbols expansion (Tom Tromey, BZ 787487).
  - Install also gdb-gdb.py pretty printers.
  * Thu Feb  9 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-11.fc17
  - Fix possible NULL crash in find_charset_names (Tom Tromey, BZ 786091).
  - [ppc*] Fix build failure due to GCC aliasing warning (BZ 786504).
* Tue Jun 12 2012 cfarrell@suse.com
- license update: GPL-3.0+ and GPL-3.0-with-GCC-exception and LGPL-2.1+ and
  LGPL-3.0+
  SPDX format
* Wed May  9 2012 coolo@suse.com
- Fix the minimum to get it through factory-auto
* Tue Apr  3 2012 rguenther@suse.com
- Fixup missed debuginfo handling SUSE specifics.
* Thu Jan 26 2012 rguenther@suse.com
- Merge from gdb-7.4.50.20120120-10.fc17.src.rpm.
  * Sat Jan 21 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-10.fc17
  - Rebase to FSF GDB 7.4.50.20120120.
  - Drop the g77 .spec provisioning as it has been fixed in FSF GDB.
  * Thu Jan 19 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120103-9.fc17
  - Enable smaller %%{_bindir}/gdb in future by no longer using -rdynamic.
  - Make --enablerepo to use '*-debug*' for RHEL compatibility (BZ 781571).
  - On older RHELs make readline bundled again (BZ 701131).
  - Fix build compatibility with RHEL-5 due to false noarch build.
  * Wed Jan 11 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120103-8.fc17
  - Disable unexpected GDB directories relocatability.
  * Wed Jan 11 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120103-7.fc17
  - Fix BuildRequires for RHEL compatibility (BZ 701131).
  * Wed Jan 11 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120103-6.fc17
  - Provide %%%%snap timestamp for: Provides: bundled(librarypackage)
  - Replace %%%%define by %%%%global.
  - Replace Java in Summary with Fortran (only GCC-compiled Java is supported).
  - Unbundle readline-6.2 with a workaround of skipped "ask" (BZ 701131).
  - Work around readline-6.2 incompatibility not asking for --more-- (BZ 701131).
  * Sat Jan  7 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120103-5.fc17
  - Mark %%{_sysconfdir}/gdbinit as %%%%config(noreplace).
  - Add appropriate: Provides: bundled(librarypackage).
  - Remove excessive explicit Requires: librarypackage.
  * Thu Jan  5 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120103-4.fc17
  - Fix linking on non-x86* (such as s390*) after libgdb.a removal.
  * Wed Jan  4 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120103-3.fc17
  - Reinclude gdb-dlopen-stap-probe.patch (missing in Fedora glibc - BZ 752476).
  * Tue Jan  3 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120103-2.fc17
  - Fix SystemTap support regression on i686 (Sergio Durigan Junior).
  * Tue Jan  3 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120103-1.fc17
  - Rebase to FSF GDB 7.4.50.20120103.
  * Mon Nov 28 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.3.50.20110722-11.fc17
  - No longer build bundled libstdc++ pretty printers on RHELs >= 7.
  * Sat Nov 5 2011 Sergio Durigan Junior <sergiodj@redhat.com> - 7.3.50.20110722-10.fc16
  - Backport fix for crash in cp_scan_for_anonymous_namespace
    (Aleksandar Ristovski, BZ 750341).
  * Fri Oct 14 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.3.50.20110722-9.fc16
  - Backport `info os processes' crash fix - for Eclipse (Pedro Alves, BZ 746294).
  * Tue Oct 11 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.3.50.20110722-8.fc16
  - Fix PIE testsuite run; new lib/future.exp hack and use -fPIC instead of -fPIE.
  * Mon Sep 26 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.3.50.20110722-7.fc16
  - [vla] Fix VLA arrays displayed in `bt full' (BZ 738482).
  - Fix DW_OP_GNU_implicit_pointer for DWARF32 v3+ on 64-bit arches.
  - Fix internal error on some optimized-out values.
  * Tue Aug 16 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.3.50.20110722-6.fc16
  - Python command/function auto-loading (Phil Muldoon, BZ 730976).
  - Work around PR libc/13097 "linux-vdso.so.1" warning message.
  - [TUI] Fix stepi on stripped code.
  - Add BuildRequires: systemtap-sdt-devel for archer-sergiodj-stap-patch-split.
  * Wed Aug 10 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.3.50.20110722-5.fc16
  - Fix dlopen of libpthread.so, patched glibc required (Gary Benson, BZ 669432).
  * Tue Aug  9 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.3.50.20110722-4.fc16
  - Improve GDB performance on inferior dlopen calls (Gary Benson, BZ 698001).
  - [python] Fix crash when pretty printer fails (Phil Muldoon, BZ 712715).
  - Fix crash on invalid C++ mangled names (BZ 729283).
  * Fri Jul 29 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.3.50.20110722-3.fc16
  - Fix regression from VLA merge affecting -O0 -g watchpoints.
  * Fri Jul 29 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.3.50.20110722-2.fc16
  - Include gcc -g3 .debug_macro implementation by Tom Tromey.
  * Sat Jul 23 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.3.50.20110722-1.fc16
  - Rebase to FSF GDB 7.3.50.20110722.
  - Improve gcc-4.6 stdarg false prologue end workaround (GDB PR 12435 + GCC PR 47471).
* Wed Oct 12 2011 rguenther@suse.com
- Add patch to use old ptrace interface on powerpc to fix watchpoint
  issues.  [bnc#718313]
* Thu Aug  4 2011 rguenther@novell.com
- Merge from gdb-7.3-41.fc15.src.rpm.  [fate#310741]
  * Tue Jul 26 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.3-41.fc15
  - Rebase to the final FSF GDB 7.3 release.
  - Improve gcc-4.6 stdarg false prologue end workaround (GDB PR 12435 + GCC PR 47471).
  * Sun Jul  3 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.90.20110703-40.fc15
  - Rebase to FSF GDB 7.2.90.20110703 (which is a 7.3 pre-release).
  - Adjust the `print errno' patch due to the DW_AT_linkage_name following again.
  * Fri Jun 24 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.90.20110525-39.fc15
  - Fix install-info for the gdb-doc subpackage (BZ 715228).
* Thu Jun 16 2011 rguenther@novell.com
- Merge from gdb-7.2.90.20110525-38.fc15.src.rpm.  [fate#310741]
  * Wed May 25 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.90.20110525-38.fc15
  - Rebase to FSF GDB 7.2.90.20110525 (which is a 7.3 pre-release).
  - [stap] Fix double free (Sergio Durigan Junior).
  * Tue May  3 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.90.20110429-37.fc15
  - Search also for .<seqno> files in /usr/lib/debug/.build-id (BZ 641377).
* Wed May 18 2011 rguenther@novell.com
- Merge from gdb-7.2.90.20110429-36.fc15.src.rpm.
  * Mon May  2 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.90.20110429-36.fc15
  - Bundle readline-6.2 with a workaround of skipped "ask" (BZ 701131).
  - Use --without-system-readline, disable Requires and BuildRequires of readline.
  - Drop gdb-6.5-readline-long-line-crash.patch and gdb-readline-6.0-signal.patch.
  * Fri Apr 29 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.90.20110429-35.fc15
  - Rebase to FSF GDB 7.2.90.20110429 (which is a 7.3 pre-release).
  - Fix -O2 -g breakpoints internal error + prologue skipping (BZ 612253).
  - Fix case insensitive symbols for Fortran by iFort (BZ 645773).
  - Fix physname-related CU expansion issue for C++ (PR 12708).
  - Fix Python access to inlined frames (BZ 694824).
  * Mon Apr 11 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.90.20110411-34.fc15
  - Rebase to FSF GDB 7.2.90.20110411 (which is a 7.3 pre-release).
  - Include the proper fix for anonymous struct typedefs (Tom Tromey, BZ 672230).
  * Wed Mar 30 2011 Fabio M. Di Nitto <fdinitto@redhat.com> - 7.2.50.20110328-33.fc15
  - Cleanup spec file to add sparc|sparcv9|sparc64.
  - Add sparc specific workarounds to toolchain badness:
  - disable mmap in bdf/ via --without-mmap configure option.
  - add patch to not build mmap support on sparc for gdb/.
  - gdb code is NOT at fault, but we need a working gdb while we sort out
    the toolchain and rebuild all packages. this workaround is NOT for upstream.
  * Tue Mar 29 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110328-32.fc15
  - Fix occasional crash on `print errno' with no -pthread and no -g3 (BZ 690908).
* Thu Apr 14 2011 rguenther@novell.com
- Merge from gdb-7.2.50.20110328-31.fc15.src.rpm.
  * Mon Mar 28 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110328-31.fc15
  - Rebase to FSF GDB 7.2.50.20110328 (which is a 7.3 pre-release).
  - Bundle %%%%{libstdcxxpython}.tar.bz2 unconditionally - for rebulds on RHELs.
  * Sun Mar 20 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110320-30.fc15
  - Fix threading internal error on corrupted memory (BZ 677654).
  - Fix i386 rwatch+awatch before run (BZ 688788, on top of BZ 541866).
  * Sun Mar 20 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110320-29.fc15
  - Rebase to FSF GDB 7.2.50.20110320 (which is a 7.3 pre-release).
  - Merge archer-sergiodj-stap, the SystemTap probes breakpoints feature.
  - [stap] Fix -O2 warnings.
  - Fix Ada support crash on uninitialized gdbarch.
  * Sat Mar  5 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110305-28.fc15
  - Rebase to FSF GDB 7.2.50.20110305 (which is a 7.3 pre-release).
  * Fri Feb 25 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110222-27.fc15
  - Include doc also in the PDF form; new BuildRequires: texinfo-tex.
  * Wed Feb 23 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110222-26.fc15
  - Rebase to FSF GDB 7.2.50.20110222 (which is a 7.3 pre-release).
  - Fix attach/core-load of {,un}prelinked i386 libs (bugreport by Michal Toman).
  * Mon Feb 21 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110218-25.fc15
  - Drop %%%%{_datadir}/gdb/syscalls/* for unsupported arches.
  * Fri Feb 18 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110218-24.fc15
  - Rebase to FSF GDB 7.2.50.20110218 (which is a 7.3 pre-release).
  - [vla] Fox Fortran vector slices for allocated arrays (for BZ 609782).
  * Tue Feb 15 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110213-23.fc15
  - Move the GFDL License to gdb-doc.
  * Tue Feb 15 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110213-22.fc15
  - Fix gdb-doc Group to be Documentation, also provide it as noarch.
  * Tue Feb 15 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110213-21.fc15
  - Drop non-user (gdbint) and obsolete (stabs) documentation.
  - Install also HTML files besides the INFO file.
  - Create new subpackage gdb-doc for both INFO and HTML files.
  * Sun Feb 13 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110213-20.fc15
  - Rebase to FSF GDB 7.2.50.20110213 (which is a 7.3 pre-release).
  - Fix occasionall unfound source lines (affecting at least glibc debugging).
  - Fix const/volatile qualifiers of C++ types (PR c++/12328).
  - Be backward compatible for --rebuild with <=fc14 librpm.so.1.
- Revert documentation split.
* Thu Mar  3 2011 rguenther@novell.com
- Merge from gdb-7.2.50.20110206-19.fc15.src.rpm.
  * Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 7.2.50.20110206-19
  - Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild
  * Sun Feb  6 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110206-18.fc15
  - Fix regressions on C++ names resolving (PR 11734, PR 12273, Keith Seitz).
  * Sun Feb  6 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110206-17.fc15
  - Rebase to FSF GDB 7.2.50.20110206 (which is a 7.3 pre-release).
  * Thu Jan 27 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110125-16.fc15
  - Fix Python new-backtrace command (BZ 672235, Phil Muldoon).
  * Wed Jan 26 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110125-15.fc15
  - Temporary fix of F15 gcc-4.6 child DIEs of DW_TAG_typedef (BZ 672230).
  - Workaround gcc-4.6 stdarg false prologue end (GDB PR 12435 + GCC PR 47471).
  * Tue Jan 25 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110125-14.fc15
  - Rebase to FSF GDB 7.2.50.20110125 (which is a 7.3 pre-release).
  - Fix discontiguous address ranges in .gdb_index - v3->v4 (BZ 672281).
  - Fix DWARF-3+ DW_AT_accessibility default assumption for F15 gcc-4.6.
  * Thu Jan 20 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110117-13.fc15
  - Use librpm.so.2 for rpm-4.9.0 in Fedora 15.
  * Mon Jan 17 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110117-12.fc15
  - Use %%%%{?dist} for sanity checking tools compliance (suggested by Petr Muller).
  * Mon Jan 17 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110117-11.fc15
  - Rebase to FSF GDB 7.2.50.20110117 (which is a 7.3 pre-release).
  - Fix callback-mode readline-6.0 regression for CTRL-C (for RHEL-6.0).
  - Fix occasional NULL dereference of the readline-6.0 workaround (BZ 575516).
  * Sat Jan 15 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110107-10.fc15
  - [delayed-symfile] Test a backtrace regression on CFIs without DIE (BZ 614604).
  - [archer-tromey-delayed-symfile] New test gdb.dwarf2/dw2-aranges.exp.
  - [archer-keiths-expr-cumulative+upstream] Import C++ testcases.
  - testsuite: Fix gdb-test-expr-cumulative-archer.patch compatibility.
  * Fri Jan  7 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110107-9.fc15
  - Remove --with-pythondir as no longer valid.
  - Provide %%{_bindir}gdb-add-index even on RHEL-5.
  - Provide again libstdc++ pretty printers for any RHEL.
  * Fri Jan  7 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110107-8.fc15
  - Rebase to FSF GDB 7.2.50.20110107 (which is a 7.3 pre-release).
  - Import archer-tromey-python (BZ 666177, branch update by Phil Muldoon).
  * Tue Jan  4 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110104-7.fc15
  - Rebase to FSF GDB 7.2.50.20110104 (which is a 7.3 pre-release).
  - New testcase py-prettyprint.exp:print hint_error (for BZ 611569, BZ 629236).
  - New test gdb.arch/x86_64-pid0-core.exp for kernel PID 0 cores (BZ 611435).
  * Sat Jan  1 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20101231-6.fc15
  - Fix --with-system-readline doc build upstream regression.
  * Sat Jan  1 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20101231-5.fc15
  - Rebase to FSF GDB 7.2.50.20101231 (which is a 7.3 pre-release).
  - Remove gdb-6.3-bt-past-zero-20051201.patch, gdb-archer-ada.patch and
    gdb-6.3-framepczero-20040927.patch already removed from .spec before.
  - Remove gdb-6.5-dwarf-stack-overflow.patch, upstreamed (Tom Tromey).
  - Remove gdb-6.6-bz225783-gdb-debuginfo-paths.patch, upstreamed (Tom Tromey).
  - Remove gdb-6.6-readline-system.patch, reimplemented upstream (Tom Tromey).
  - Remove gdb-bz642879-elfread-sigint-stale.patch, upstreamed (Jan Kratochvil).
  - Remove gdb-next-over-throw.patch, upstreamed (Tom Tromey).
  * Mon Dec 27 2010 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20101117-4.fc15
  - Provide stub %%%%{_sysconfdir}/gdbinit (BZ 651232).
  * Mon Dec 27 2010 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20101117-3.fc15
  - Fix ppc* compilation of PRPSINFO in the core files (BZ 662995, for BZ 254229).
  - Fix (disable) non-x86* compilation of libinproctrace.so (for BZ 662995).
  * Thu Nov 18 2010 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20101117-2.fc15
  - Drop gdb-6.8-glibc-headers-compat.patch: GNU/Linux irrelevant (Tom Tromey).
  - Drop gdb-6.3-terminal-fix-20050214.patch: The bug is not reproducible.
  - Drop gdb-6.7-kernel-headers-compat.patch: kernel-headers seem to be fixed.
  - Drop gdb-archer-ada.patch: No longer needed for Ada (Keith Seitz).
  - New PR backtrace/12237, drop gdb-6.3-framepczero-20040927.patch
    gdb-6.3-bt-past-zero-20051201.patch as they already had no effect.
  - Drop gdb-6.8-gcc35998-ada-memory-trash.patch as a different fix is upstream.
  - Drop gdb-6.3-inheritance-20050324.patch: the call is redundent (Tom Tromey).
  - Drop gdb-6.3-large-core-20051206.patch: obsoleted by MAX_COPY_BYTES.
  * Thu Nov 18 2010 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20101117-1.fc15
  - Rebase to FSF GDB 7.2.50.20101117 (which is a 7.3 pre-release).
  * Sun Nov  7 2010 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2-25.fc14
  - iFort compat. - case insensitive DWARF not in lowercase (BZ 645773).
  * Thu Oct 14 2010 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2-24.fc14
  - Add gdb.spec comments on the *.patch files upstream merge status.
  * Thu Oct 14 2010 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2-23.fc14
  - Workaround librpm BZ 643031 due to its unexpected exit() calls (BZ 642879).
  - Fix crash on CTRL-C while reading an ELF symbol file (BZ 642879).
  * Tue Oct 12 2010 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2-22.fc14
  - testsuite: Provide missing lib/gdb-python.exp (for BZ 639089).
  * Tue Oct 12 2010 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2-21.fc14
  - Fix python stale error state, also fix its save/restore (BZ 639089).
  - Fix inferior exec of new PIE x86_64 (BZ 638979).
  * Tue Oct 12 2010 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2-20.fc14
  - Fixup Release for 20.fc14.
  * Tue Oct 12 2010 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2-19.fc14
  - Use .gdb_index v3 to fix excessive resources rqmnts (BZ 640634, Tom Tromey).
  * Wed Oct  6 2010 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2-18.fc14
  - Fix false warning: non-absolute filename: <the main exec. file> (BZ 640648).
  * Thu Sep 30 2010 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2-17.fc14
  - New Conflicts: elfutils < 0.149 due to the .gdb_index .debug support.
* Mon Dec  6 2010 rguenther@novell.com
- On SLE10 package libinproctrace in the main gdb package.
* Wed Oct 13 2010 rguenther@novell.com
- Merge from gdb-7.2-16.fc14.src.rpm.
* Mon Sep 13 2010 rguenther@novell.com
- Change python-base from recommends to requires, gdb no longer
  works without some basic python modules.  [bnc#638858]
* Mon Sep  6 2010 rguenther@novell.com
- Merge from gdb-7.2-1.fc14.src.rpm.
* Wed Aug 25 2010 rguenther@novell.com
- Backport fix for gcore not handling GNU_RELRO sections.  [bnc#596646]
* Wed Aug 25 2010 rguenther@novell.com
- Merge from gdb-7.1-33.fc13.src.rpm.
* Fri Aug  6 2010 rguenther@novell.com
- Backport fix for setting of VSX registers.  [bnc#626970]
* Thu Aug  5 2010 rguenther@novell.com
- Merge from gdb-7.1-30.fc13.src.rpm.
* Thu Aug  5 2010 rguenther@novell.com
- For SLE10 do not build a separate gdbserver package.
* Thu Jul 22 2010 rguenther@novell.com
- Merge from gdb-7.1-29.fc13.src.rpm.
* Tue Jun  1 2010 rguenther@novell.com
- Fix build on hppa fix.
* Tue Jun  1 2010 bg@novell.com
- Fix build on hppa.
* Fri May 21 2010 rguenther@novell.com
- Merge from gdb-7.1-20.fc13.src.rpm.
* Thu Apr 22 2010 aj@suse.de
- Add upstream change to fix build with -Werror
* Thu Apr 15 2010 rguenther@novell.com
- Merge from gdb-7.1-12.fc13.src.rpm.
- Re-write history to match SLE11 SP1 changelog
  * Drop some more strange RHEL stuff.
  * Fix build for SLE10.
* Mon Mar 15 2010 rguenther@novell.com
- Fix info documentation registering.  [bnc#588278]
* Thu Feb 11 2010 kukuk@suse.de
- Re-Add baselibs.conf
* Thu Oct 22 2009 rguenther@suse.de
- Merge from gdb-7.0-2.fc12.src.rpm.  [fate#304116]
  [bnc#488132] [bnc#498749]
* Mon Oct 19 2009 rguenther@suse.de
- Recommend python-base.
* Mon Oct 12 2009 rguenther@suse.de
- Fix python dependency.
* Wed Oct  7 2009 crrodriguez@opensuse.org
- fix info files (un)installation.
* Mon Oct  5 2009 rguenther@suse.de
- Merge from gdb-6.8.91.20090930-2.fc12.src.rpm.
* Thu Sep 24 2009 rguenther@suse.de
- Merge from gdb-6.8.91.20090921-1.fc12.src.rpm.
* Mon Sep 14 2009 rguenther@suse.de
- Merge from gdb-6.8.50.20090910-1.fc12.src.rpm.
* Mon Aug 24 2009 rguenther@suse.de
- Fix gdb-6.3-ia64-sigtramp-frame-20050708.patch patch to allow
  ia64 to build again.
* Mon Aug 24 2009 rguenther@suse.de
- Merge from gdb-6.8.50.20090818-4.fc12.src.rpm.
* Mon Aug 17 2009 rguenther@suse.de
- Merge from gdb-6.8.50.20090811-2.fc12.src.rpm.
* Tue Aug 11 2009 rguenther@suse.de
- Remove no longer applied patches.
* Thu Aug  6 2009 rguenther@suse.de
- Fixup the merge.
* Thu Aug  6 2009 rguenther@suse.de
- Merge from gdb-6.8.50.20090803-2.fc12.src.rpm.
* Tue Jul 28 2009 rguenther@suse.de
- Fix crash during debuginfo reading.
* Wed Jul  8 2009 rguenther@suse.de
- Drop fixes done upstream.
* Wed Jun 17 2009 matz@suse.de
- Apply fix for backtraces without unwind info again.  [#390722]
- Disable gdb-6.5-bz218379-ppc-solib-trampoline-fix.patch, it's not
  necessary anymore and breaks the above.
* Wed May 27 2009 rguenther@suse.de
- Merge FC11 update 23.
  - Fix crashes due to (missing) varobj revalidation, for VLA (for brc#377541).
  - Archer update to the snapshot: e2812eadef2c15baeccd003e11fdf3fbc0b90dc2
  - Archer backport: 58dcda94ac5d6398f47382505e9d3d9d866d79bf
    + f3de7bbd655337fe6705aeaafcc970deff3dd5d5
  - Implement Fortran modules namespaces (brc#466118).
* Mon May 18 2009 rguenther@suse.de
- Add patch to fix handling of string DW_AT_const_values.  [bnc#329420]
- Verified
  * Fix printing of 'inf'.  [bnc#466266]
  * Stepping through templates.  [bnc#414230]
  * gcore script.  [fate#303462]
* Thu May 14 2009 rguenther@suse.de
- Change reported version to mention SUSE instead of Fedora.
- Fix handling of bogus global namespace DIEs from GCC 4.1.  [bnc#329420]
- Fix Power7 DFP detection.  [bnc#492331]
* Thu May  7 2009 rguenther@suse.de
- Fix build for SLE10.  [fate#305977]
- Adjust missing debug packages suggested install command.
* Wed Apr 29 2009 rguenther@suse.de
- Adjust package name and release to not contain macros.
* Mon Apr 27 2009 rguenther@suse.de
- Disable rpm support for locating debug info packages.
* Mon Apr 27 2009 rguenther@suse.de
- Switch to Fedora 11 source RPM.
  * includes partially merge from Archer.  [bnc#329420, bnc#497141,
    bnc#492782]
* Tue Mar 10 2009 rguenther@suse.de
- Add VLA support patch from Fedora to fix possible
  dwarf_expr_frame_base NULL checking regression.
- Fix readline incompatibility.
* Mon Mar  2 2009 rguenther@suse.de
- Integrate support for transparently debugging inline functions.
* Mon Feb 16 2009 schwab@suse.de
- Update to head to trunk.
* Tue Feb  3 2009 schwab@suse.de
- Fix merge error.
* Thu Jan 22 2009 schwab@suse.de
- Add updates for Cell combined debugger.
* Tue Jan 20 2009 schwab@suse.de
- Do not call get_frame_arch for NULL frame pointers.
- Remove deprecated_safe_get_selected_frame call from read_var_value.
* Fri Jan 16 2009 bwalle@suse.de
- Recommend Python for GDB to prevent strange error messages to
  be presented to the user in the default case.
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Nov 20 2008 schwab@suse.de
- Update to head of trunk.
- Don't lose running state of the inferior.
- Fix dangling pointers after following fork.
* Sun Nov  9 2008 schwab@suse.de
- Update .debug_line parser patch.
* Mon Nov  3 2008 schwab@suse.de
- Update to head of trunk.
- Fix auxv decoding.
* Mon Nov  3 2008 schwab@suse.de
- Revert broken change from jblunck.
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Tue Oct 28 2008 jblunck@suse.de
- Fix segfault when reading line number program (bnc #439457).
* Mon Oct 27 2008 schwab@suse.de
- Complain about invalid line number program.
* Tue Oct  7 2008 schwab@suse.de
- Fix crash.
* Wed Sep 24 2008 schwab@suse.de
- Update to head of trunk.
- Add POWER7 support.
- Add gcore.
- Add spu-elf to list of targets.
* Fri Sep 12 2008 schwab@suse.de
- Update to head of trunk.
- Add Cell combined debugger patch.
* Thu Sep  4 2008 schwab@suse.de
- Update to head of trunk.
* Fri Aug 15 2008 schwab@suse.de
- Update to head of trunk.
* Fri Aug  8 2008 schwab@suse.de
- Update to head of trunk.
- Enable multi-target support.
* Fri Jul 18 2008 schwab@suse.de
- Update to head of trunk.
* Mon Jul  7 2008 schwab@suse.de
- Update to head of trunk.
* Wed Jun 18 2008 schwab@suse.de
- Update to head of trunk.
* Fri May 23 2008 matz@suse.de
- Try harder to provide backtraces without debuginfo on i386.  [bnc #390722]
* Wed May 21 2008 schwab@suse.de
- Fix assertion failure.
* Fri May  9 2008 schwab@suse.de
- Split off gdbserver.
- Fix watchpoints.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Fri Mar 28 2008 schwab@suse.de
- Update to gdb 6.8.
  * New native configurations
  NetBSD/hppa			hppa*-*netbsd*
  Xtensa GNU/Linux		xtensa*-*-linux*
  * New targets
  NetBSD/hppa			hppa*-*-netbsd*
  Xtensa GNU/Lunux		xtensa*-*-linux*
  * Change in command line behavior -- corefiles vs. process ids.
    When the '-p NUMBER' or '--pid NUMBER' options are used, and
    attaching to process NUMBER fails, GDB no longer attempts to open a
    core file named NUMBER.  Attaching to a program using the -c option
    is no longer supported.  Instead, use the '-p' or '--pid' options.
  * GDB can now be built as a native debugger for debugging Windows x86
  (mingw32) Portable Executable (PE) programs.
  * Pending breakpoints no longer change their number when their address
  is resolved.
  * GDB now supports breakpoints with multiple locations,
  including breakpoints on C++ constructors, inside C++ templates,
  and in inlined functions.
  * GDB's ability to debug optimized code has been improved.  GDB more
  accurately identifies function bodies and lexical blocks that occupy
  more than one contiguous range of addresses.
  * Target descriptions can now describe registers for PowerPC.
  * The GDB remote stub, gdbserver, now supports the AltiVec and SPE
  registers on PowerPC targets.
  * The GDB remote stub, gdbserver, now supports thread debugging on GNU/Linux
  targets even when the libthread_db library is not available.
  * The GDB remote stub, gdbserver, now supports the new file transfer
  commands (remote put, remote get, and remote delete).
  * The GDB remote stub, gdbserver, now supports run and attach in
  extended-remote mode.
  * hppa*64*-*-hpux11* target broken
    The debugger is unable to start a program and fails with the following
    error: "Error trying to get information about dynamic linker".
    The gdb-6.7 release is also affected.
  * GDB now supports the --enable-targets= configure option to allow
  building a single GDB executable that supports multiple remote
  target architectures.
  * GDB now supports debugging C and C++ programs which use the
  Decimal Floating Point extension.  In addition, the PowerPC target
  now has a set of pseudo-registers to inspect decimal float values
  stored in two consecutive float registers.
  * The -break-insert MI command can optionally create pending
  breakpoints now.
  * Improved support for debugging Ada
    Many improvements to the Ada language support have been made.  These
    include:
  - Better support for Ada2005 interface types
  - Improved handling of arrays and slices in general
  - Better support for Taft-amendment types
  - The '{type} ADDRESS' expression is now allowed on the left hand-side
  of an assignment
  - Improved command completion in Ada
  - Several bug fixes
  * New commands
  set print frame-arguments (all|scalars|none)
  show print frame-arguments
    The value of this variable can be changed to control which argument
    values should be printed by the debugger when displaying a frame.
  remote put
  remote get
  remote delete
    Transfer files to and from a remote target, and delete remote files.
  * New MI commands
  - target-file-put
  - target-file-get
  - target-file-delete
    Transfer files to and from a remote target, and delete remote files.
  * New remote packets
  vFile:open:
  vFile:close:
  vFile:pread:
  vFile:pwrite:
  vFile:unlink:
    Open, close, read, write, and delete files on the remote system.
  * GDB on GNU/Linux and HP/UX can now debug through "exec" of a new
  process.
  vAttach
    Attach to an existing process on the remote system, in extended-remote
    mode.
  vRun
    Run a new process on the remote system, in extended-remote mode.
* Wed Mar  5 2008 schwab@suse.de
- Update to head of gdb_6_8-branch.
* Thu Feb 14 2008 schwab@suse.de
- Update to head of trunk.
* Thu Jan 31 2008 schwab@suse.de
- Update to head of trunk.
* Thu Jan 10 2008 schwab@suse.de
- Update to head of trunk.
* Mon Nov 12 2007 schwab@suse.de
- Update to gdb 6.7.1.
  * hppa*64*-*-hpux11* target broken
    The debugger is unable to start a program and fails with the following
    error: "Error trying to get information about dynamic linker".
    The gdb-6.7 release is also affected.
* Fri Oct 19 2007 olh@suse.de
- allow build with old distributions, libexpat-devel is new in 10.3
* Thu Oct 11 2007 schwab@suse.de
- Update to gdb 6.7.
  * Resolved 101 resource leaks, null pointer dereferences, etc. in gdb,
  bfd, libiberty and opcodes, as revealed by static analysis donated by
  Coverity, Inc. (http://scan.coverity.com).
  * When looking up multiply-defined global symbols, GDB will now prefer the
  symbol definition in the current shared library if it was built using the
  - Bsymbolic linker option.
  * When the Text User Interface (TUI) is not configured, GDB will now
  recognize the -tui command-line option and print a message that the TUI
  is not supported.
  * The GDB remote stub, gdbserver, now has lower overhead for high
  frequency signals (e.g. SIGALRM) via the QPassSignals packet.
  * GDB for MIPS targets now autodetects whether a remote target provides
  32-bit or 64-bit register values.
  * Support for C++ member pointers has been improved.
  * GDB now understands XML target descriptions, which specify the
  target's overall architecture.  GDB can read a description from
  a local file or over the remote serial protocol.
  * Vectors of single-byte data use a new integer type which is not
  automatically displayed as character or string data.
  * The /s format now works with the print command.  It displays
  arrays of single-byte integers and pointers to single-byte integers
  as strings.
  * Target descriptions can now describe target-specific registers,
  for architectures which have implemented the support (currently
  only ARM, M68K, and MIPS).
  * GDB and the GDB remote stub, gdbserver, now support the XScale
  iWMMXt coprocessor.
  * The GDB remote stub, gdbserver, has been updated to support
  ARM Windows CE (mingw32ce) debugging, and GDB Windows CE support
  has been rewritten to use the standard GDB remote protocol.
  * GDB can now step into C++ functions which are called through thunks.
  * GDB for the Cell/B.E. SPU now supports overlay debugging.
  * The GDB remote protocol "qOffsets" packet can now honor ELF segment
  layout.  It also supports a TextSeg= and DataSeg= response when only
  segment base addresses (rather than offsets) are available.
  * The /i format now outputs any trailing branch delay slot instructions
  immediately following the last instruction within the count specified.
  * The GDB remote protocol "T" stop reply packet now supports a
  "library" response.  Combined with the new "qXfer:libraries:read"
  packet, this response allows GDB to debug shared libraries on targets
  where the operating system manages the list of loaded libraries (e.g.
  Windows and SymbianOS).
  * The GDB remote stub, gdbserver, now supports dynamic link libraries
  (DLLs) on Windows and Windows CE targets.
  * GDB now supports a faster verification that a .debug file matches its binary
  according to its build-id signature, if the signature is present.
  * New commands
  set remoteflow
  show remoteflow
    Enable or disable hardware flow control (RTS/CTS) on the serial port
    when debugging using remote targets.
  set mem inaccessible-by-default
  show mem inaccessible-by-default
    If the target supplies a memory map, for instance via the remote
    protocol's "qXfer:memory-map:read" packet, setting this variable
    prevents GDB from accessing memory outside the memory map.  This
    is useful for targets with memory mapped registers or which react
    badly to accesses of unmapped address space.
  set breakpoint auto-hw
  show breakpoint auto-hw
    If the target supplies a memory map, for instance via the remote
    protocol's "qXfer:memory-map:read" packet, setting this variable
    lets GDB use hardware breakpoints automatically for memory regions
    where it can not use software breakpoints.  This covers both the
    "break" command and internal breakpoints used for other commands
    including "next" and "finish".
  catch exception
  catch exception unhandled
    Stop the program execution when Ada exceptions are raised.
  catch assert
    Stop the program execution when an Ada assertion failed.
  set sysroot
  show sysroot
    Set an alternate system root for target files.  This is a more
    general version of "set solib-absolute-prefix", which is now
    an alias to "set sysroot".
  info spu
    Provide extended SPU facility status information.  This set of
    commands is available only when debugging the Cell/B.E. SPU
    architecture.
  * New native configurations
  OpenBSD/sh			sh*-*openbsd*
  set tdesc filename
  unset tdesc filename
  show tdesc filename
    Use the specified local file as an XML target description, and do
    not query the target for its built-in description.
  * New targets
  OpenBSD/sh			sh*-*-openbsd*
  MIPS64 GNU/Linux (gdbserver)	mips64-linux-gnu
  Toshiba Media Processor		mep-elf
  * New remote packets
  QPassSignals:
    Ignore the specified signals; pass them directly to the debugged program
    without stopping other threads or reporting them to GDB.
  qXfer:features:read:
    Read an XML target description from the target, which describes its
    features.
  qXfer:spu:read:
  qXfer:spu:write:
    Read or write contents of an spufs file on the target system.  These
    packets are available only on the Cell/B.E. SPU architecture.
  qXfer:libraries:read:
    Report the loaded shared libraries.  Combined with new "T" packet
    response, this packet allows GDB to debug shared libraries on
    targets where the operating system manages the list of loaded
    libraries (e.g. Windows and SymbianOS).
  * Removed targets
  Support for these obsolete configurations has been removed.
  alpha*-*-osf1*
  alpha*-*-osf2*
  d10v-*-*
  hppa*-*-hiux*
  i[34567]86-ncr-*
  i[34567]86-*-dgux*
  i[34567]86-*-lynxos*
  i[34567]86-*-netware*
  i[34567]86-*-sco3.2v5*
  i[34567]86-*-sco3.2v4*
  i[34567]86-*-sco*
  i[34567]86-*-sysv4.2*
  i[34567]86-*-sysv4*
  i[34567]86-*-sysv5*
  i[34567]86-*-unixware2*
  i[34567]86-*-unixware*
  i[34567]86-*-sysv*
  i[34567]86-*-isc*
  m68*-cisco*-*
  m68*-tandem-*
  mips*-*-pe
  rs6000-*-lynxos*
  sh*-*-pe
  * Other removed features
  target abug
  target cpu32bug
  target est
  target rom68k
  Various m68k-only ROM monitors.
  target hms
  target e7000
  target sh3
  target sh3e
  Various Renesas ROM monitors and debugging interfaces for SH and
  H8/300.
  target ocd
  Support for a Macraigor serial interface to on-chip debugging.
  GDB does not directly support the newer parallel or USB
  interfaces.
  DWARF 1 support
  A debug information format.  The predecessor to DWARF 2 and
  DWARF 3, which are still supported.
  Support for the HP aCC compiler on HP-UX/PA-RISC
  SOM-encapsulated symbolic debugging information, automatic
  invocation of pxdb, and the aCC custom C++ ABI.  This does not
  affect HP-UX for Itanium or GCC for HP-UX/PA-RISC.  Code compiled
  with aCC can still be debugged on an assembly level.
  MIPS ".pdr" sections
  A MIPS-specific format used to describe stack frame layout
  in debugging information.
  Scheme support
  GDB could work with an older version of Guile to debug
  the interpreter and Scheme programs running in it.
  set mips stack-arg-size
  set mips saved-gpreg-size
  Use "set mips abi" to control parameter passing for MIPS.
* Mon Oct  1 2007 schwab@suse.de
- Update to head of gdb_6_7-branch.
* Mon Sep 24 2007 schwab@suse.de
- Fix internal error [#309928].
* Thu Jul 26 2007 schwab@suse.de
- Update to head of trunk.
* Fri Jul 13 2007 schwab@suse.de
- Update to head of trunk.
* Sun Jun 24 2007 schwab@suse.de
- Fix annotations for commands prompt.
* Thu Jun 21 2007 schwab@suse.de
- Update to head of trunk.
* Fri Jun  8 2007 schwab@suse.de
- Update to head of trunk.
* Fri May 11 2007 schwab@suse.de
- Update to head of trunk.
* Fri Apr 13 2007 schwab@suse.de
- Avoid crash on object with no text section [#176306].
* Wed Apr 11 2007 schwab@suse.de
- Handle non-threaded processes in gstack [#262694].
* Sun Apr  1 2007 schwab@suse.de
- Properly decode CR register number.
* Thu Mar 29 2007 schwab@suse.de
- Update solib-extract-address patch.
* Tue Mar 20 2007 schwab@suse.de
- Update single stepping patch again [#154486].
* Fri Mar 16 2007 schwab@suse.de
- Update single stepping patch [#154486].
* Thu Mar 15 2007 schwab@suse.de
- Fix altivec vector return location [#250004].
* Mon Mar 12 2007 schwab@suse.de
- Update ppc DWARF patch to also handle broken debug info from old
  compilers.
* Thu Mar  8 2007 schwab@suse.de
- Deal with stepping over sequence of atomic insns [#154486].
* Wed Mar  7 2007 schwab@suse.de
- Improve last change.
* Tue Mar  6 2007 schwab@suse.de
- Better handling of ppc64 function descriptor symbols.
* Mon Mar  5 2007 schwab@suse.de
- Remove obsolete patch.
- Fix show endian.
* Thu Jan 11 2007 schwab@suse.de
- Fix unchecked use of PC_REGNUM.
* Wed Dec 20 2006 schwab@suse.de
- Update to gdb 6.6.
  * New targets
  Xtensa				xtensa-elf
  Cell Broadband Engine SPU	spu-elf
  * GDB can now be configured as a cross-debugger targeting native Windows
  (mingw32) or Cygwin.  It can communicate with a remote debugging stub
  running on a Windows system over TCP/IP to debug Windows programs.
  * The GDB remote stub, gdbserver, has been updated to support Windows and
  Cygwin debugging.  Both single-threaded and multi-threaded programs are
  supported.
  * The "set trust-readonly-sections" command works again.  This command was
  broken in GDB 6.3, 6.4, and 6.5.
  * Support for GNU/Linux Thread Local Storage (TLS, per-thread variables) no
  longer requires symbolic debug information (e.g. DWARF-2).
  * New commands
  set substitute-path
  unset substitute-path
  show substitute-path
    Manage a list of substitution rules that GDB uses to rewrite the name
    of the directories where the sources are located. This can be useful
    for instance when the sources were moved to a different location
    between compilation and debugging.
  set trace-commands
  show trace-commands
    Print each CLI command as it is executed.  Each command is prefixed with
    a number of `+' symbols representing the nesting depth.
    The source command now has a `-v' option to enable the same feature.
  * REMOVED features
  The ARM Demon monitor support (RDP protocol, "target rdp").
  Kernel Object Display, an embedded debugging feature which only worked with
  an obsolete version of Cisco IOS.
  The 'set download-write-size' and 'show download-write-size' commands.
  * New remote packets
  qSupported:
    Tell a stub about GDB client features, and request remote target features.
    The first feature implemented is PacketSize, which allows the target to
    specify the size of packets it can handle - to minimize the number of
    packets required and improve performance when connected to a remote
    target.
  qXfer:auxv:read:
    Fetch an OS auxilliary vector from the remote stub.  This packet is a
    more efficient replacement for qPart:auxv:read.
  * Removed remote packets
  qPart:auxv:read:
    This packet has been replaced by qXfer:auxv:read.  Only GDB 6.4 and 6.5
    used it, and only gdbserver implemented it.
* Sat Dec  2 2006 schwab@suse.de
- Update to gdb 6.5.90.
* Fri Oct 27 2006 schwab@suse.de
- Rename detach-fork to detach fork.
* Tue Oct 24 2006 schwab@suse.de
- Better fix for function descriptor handling on ppc64.
* Fri Aug 25 2006 schwab@suse.de
- Minimal support for .gnu.hash.
* Thu Aug 24 2006 schwab@suse.de
- Fix off-by-one in add_symbol_file_command [#200831].
* Fri Aug 11 2006 schwab@suse.de
- Correctly extend addresses read from link map.
* Sun Jul 16 2006 schwab@suse.de
- Fix function decriptor handing on ppc64.
* Wed Jun 21 2006 schwab@suse.de
- Update to final gdb 6.5.
* Sat Jun  3 2006 schwab@suse.de
- Update to gdb 6.5 RC 1.
* Wed May 31 2006 schwab@suse.de
- Set long double size to 16 [#180103].
* Mon May 22 2006 schwab@suse.de
- Update to gdb 6.4.90 snapshot 20060522.
* Sun Apr 23 2006 schwab@suse.de
- Add patch to avoid losing compilation directory.
- Fix a parallel build problem.
* Tue Apr  4 2006 schwab@suse.de
- Relocate PIEs.
* Sun Mar 26 2006 schwab@suse.de
- Handle .eh_frame register encoding that is different from .dwarf_frame.
- Remove obsolete patch.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 schwab@suse.de
- Add fix for PIC prologue analyzer on powerpc.
* Wed Dec 14 2005 schwab@suse.de
- Add fix for observer notify queue after attach.
* Fri Dec  2 2005 schwab@suse.de
- Update to gdb 6.4.
* Tue Nov 22 2005 schwab@suse.de
- Update to gdb 6.3.90.
* Fri Nov  4 2005 schwab@suse.de
- Update to gdb-6.3.50 snapshot 20051103.
* Mon Oct  3 2005 schwab@suse.de
- Update to gdb 6.3.50 snapshot 20051003.
* Mon Sep 19 2005 schwab@suse.de
- Fix warnings.
* Sun Aug 21 2005 schwab@suse.de
- Add DWARF CFI unwinder on ppc.
* Mon Jun 20 2005 schwab@suse.de
- Require libunwind-devel on ia64.
* Thu Jun  9 2005 schwab@suse.de
- Add patch for ia64 vDSO support and unwinding through signals and
  syscalls [#60766].
* Mon Apr 11 2005 schwab@suse.de
- Fix backtrace through vsyscall [#63483].
* Sun Apr 10 2005 schwab@suse.de
- Add patch to fix bugs in rs6000/powerpc register set functions.
- Fix a testsuite bug.
* Sun Mar  6 2005 schwab@suse.de
- Add patch to suppress fork attach/detach messages.
* Wed Mar  2 2005 schwab@suse.de
- Add patch to fix following vfork from a secondary thread.
* Mon Feb 28 2005 schwab@suse.de
- Don't ignore DW_TAG_member [#66406].
* Tue Feb  1 2005 schwab@suse.de
- Find separate debug symbol files in /usr/lib/debug by default.
* Thu Jan 27 2005 schwab@suse.de
- Add patch to handle back-to-back and nested signals.
* Thu Jan 27 2005 schwab@suse.de
- Add patch to implement reggroups for ppc.
* Wed Jan 26 2005 schwab@suse.de
- Add patch to implement PPC GNU/Linux sigtramp frame code.
* Wed Jan 12 2005 schwab@suse.de
- Don't error out when encountering an unavailable value.
* Fri Dec  3 2004 schwab@suse.de
- Downgrade errors to warnings during backtrace [#48484].
- Undocument --readnever since it may not be supported by future releases.
- Fix patches from last change.
* Fri Dec  3 2004 kukuk@suse.de
- Add --readnever option as workaround for [#48485]
* Sun Nov 14 2004 schwab@suse.de
- Add libunwind-devel to neededforbuild.
* Sat Nov 13 2004 schwab@suse.de
- Fix missing dependencies.
* Wed Nov 10 2004 schwab@suse.de
- Version 6.2.91 renamed to 6.3.
* Mon Nov  8 2004 schwab@suse.de
- Update to gdb 6.2.91 (6.3 release candidate).
* Mon Nov  8 2004 schwab@suse.de
- Revert last change.
- Fix typo.
* Mon Nov  8 2004 uli@suse.de
- fixed to build on s390*
* Mon Oct 25 2004 schwab@suse.de
- Fix building gdbserver on x86-64.
* Mon Oct 25 2004 schwab@suse.de
- Update to gdb 6.2.90.
- Use libunwind on ia64.
* Thu Sep  9 2004 schwab@suse.de
- Update to gdb 6.2.1.
* Wed Aug 25 2004 schwab@suse.de
- Fix deadlock in child_wait [#42796].
* Tue Aug 24 2004 schwab@suse.de
- Import latest changes from 6.2 branch.
* Fri Jul 30 2004 schwab@suse.de
- Update to gdb 6.2.
* Thu Jul 29 2004 schwab@suse.de
- Update to gdb 6.1.92.
* Mon Jul 26 2004 schwab@suse.de
- Fix handling of relative filenames in DWARF2 .debug_line.
* Mon Jul 19 2004 schwab@suse.de
- Update to gdb 6.1.91.
* Thu Jun 24 2004 schwab@suse.de
- Better handling of dying threads.
* Fri Jun 18 2004 schwab@suse.de
- Update to gdb 6.1.1.
* Tue May 25 2004 schwab@suse.de
- Fix handling of short lived threads [#40841].
* Sat May  1 2004 schwab@suse.de
- Restore removed hunk.
* Fri Apr 30 2004 meissner@suse.de
- applied 3 patches to fix problems on ppc64. #39394
* Sat Apr 17 2004 schwab@suse.de
- Pacify autobuild.
* Mon Apr  5 2004 schwab@suse.de
- Version 6.0.92 has been renamed to 6.1.
* Sat Apr  3 2004 schwab@suse.de
- Update to gdb 6.0.92 (6.1 release candidate).
* Tue Mar 30 2004 schwab@suse.de
- Fix invalid use of va_list.
* Mon Mar 29 2004 schwab@suse.de
- Update to gdb 6.0.91.
* Mon Mar 29 2004 schwab@suse.de
- Update to current CVS.
* Fri Mar 19 2004 schwab@suse.de
- Fix last change: don't disable testsuite.
* Wed Mar 17 2004 mludvig@suse.cz
- Added opcodes for VIA PadLock instructions.
* Tue Mar  2 2004 schwab@suse.de
- Update to gdb 6.0.90.
- Run testsuite.
* Thu Jan  8 2004 schwab@suse.de
- Fix gate area range.
* Wed Dec 10 2003 schwab@suse.de
- Support DW_TAG_subrange_type.
- Backport recent ia64 improvements from mainline.
* Tue Oct 21 2003 mludvig@
- Add support for debugging both i386 and amd64 apps by a single
  amd64 GDB binary.
* Mon Oct 20 2003 mludvig@suse.cz
- Correctly interpret symbol tables for debugging kernel modules
  (gdb6-symtab-minimal.diff)
- Fixed support for GCC variable tracking (gdb6-vartrack.diff)
- Fixed support for Fortran arrays (gdb6-fortranarray.diff)
* Tue Oct  7 2003 schwab@suse.de
- Hack to build on sparc.
* Mon Oct  6 2003 schwab@suse.de
- Update to gdb 6.0.
* Fri Oct  3 2003 kukuk@suse.de
- Remove unused tetex from neededforbuild
* Mon Sep 29 2003 schwab@suse.de
- Update to gdb 5.3.93 pre-release.
* Wed Sep 17 2003 schwab@suse.de
- Remove debugging hooks.
* Wed Sep 17 2003 schwab@suse.de
- Ignore more insns during i386 prologue decoding [#30288].
- Fix hash table mixup in bfd_simple interface.
* Tue Sep 16 2003 schwab@suse.de
- Update to gdb 5.3.92 pre-release.
  * Fixes bug 31033.
* Wed Sep  3 2003 schwab@suse.de
- Update to gdb 5.3.91 pre-release.
* Tue Aug 19 2003 schwab@suse.de
- Update to gdb 5.3.90 2003-08-19 cvs snapshot.
* Mon Jun 23 2003 kukuk@suse.de
- Fix compiling on SPARC
* Tue Jun 10 2003 schwab@suse.de
- Don't package mmalloc.info, since libmmalloc isn't included either.
* Thu May 15 2003 schwab@suse.de
- Remove unwanted files.
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Fri Apr 11 2003 mludvig@suse.cz
- Fix read_2u() function in dwarf2cfi.c
* Thu Apr 10 2003 mludvig@suse.cz
- Add 'info cfi <address>' command.
- Fix off-by-4 bug in the CFI parser.
* Mon Apr  7 2003 schwab@suse.de
- Only delete info entries when removing last version.
* Thu Mar 27 2003 schwab@suse.de
- Fix specfile.
* Thu Mar  6 2003 aj@suse.de
- Fix neededforbuild.
* Wed Feb 26 2003 mludvig@suse.cz
- Added loclist support
- Fixed eh_frame parsing problems
- Updated for proposed x86-64 ABI change
* Thu Feb  6 2003 schwab@suse.de
- Use %%install_info.
* Tue Feb  4 2003 schwab@suse.de
- Enable TUI.
* Sun Jan 26 2003 olh@suse.de
- add inital native ppc64 support
* Thu Jan  9 2003 mludvig@suse.cz
- Fixed compilation problem with last gdb-asmbtrace.diff.
  No new feature.
* Tue Jan  7 2003 mludvig@suse.cz
- Several Dwarf2 and x86-64 specific changes
  * Added ability to do backtrace from some functions
    without debug info (patch gdb-asmbtrace.diff)
  * Fixed crash on re-run of a debugged program.
  * Added some more verbosity to dwarf2cfi engine.
* Thu Dec 12 2002 schwab@suse.de
- Update to gdb 5.3.
  * GNU/Linux shared library multi-threaded performance improved.
  * ``gdbserver'' now supports multi-threaded applications on some targets
  * GDB now supports C/C++ preprocessor macros.
* Fri Oct 11 2002 aj@suse.de
- Handle gcc code generated by gcc -f-elimante-dwarf2-dups -g.
* Thu Sep 26 2002 schwab@suse.de
- Avoid installing libbfd, libopcodes, libiberty and libmmalloc [#20199].
* Wed Sep 18 2002 sf@suse.de
- added patch from mludvig to remove framepointer on x86_64
* Wed Sep  4 2002 kukuk@suse.de
- Add Patch for reading SPARC core files
* Tue Sep  3 2002 schwab@suse.de
- Remove tetex from neededforbuild.
* Wed Jul 24 2002 schwab@suse.de
- Update to gdb 5.2.1.
* Thu Jul 18 2002 mludvig@suse.de
- Fix PLT recognisation.
* Mon Jul  8 2002 schwab@suse.de
- Add fix for memory leak.
* Tue Jul  2 2002 mludvig@suse.cz
- removed my previous patches
- added a huge one suse-521-x8664.diff
* Thu Jun  6 2002 sf@suse.de
- added fpregset.diff (from mludvig@suse.de)
- added dwarf2cfi.diff (from mludvig@suse.de)
* Wed May 15 2002 sf@suse.de
- added some dwarf2-patches for x86_64
  (from mludvig@suse.de)
* Thu May  9 2002 schwab@suse.de
- Fix breakpoints on MLX bundle.
* Mon May  6 2002 schwab@suse.de
- Sparc doesn't have gdbserver either.
* Sun May  5 2002 schwab@suse.de
- Update to gdb 5.2.
- Gdbserver now available for all but alpha.
* Fri Jan 25 2002 schwab@suse.de
- Update to gdb 5.1.1.
* Thu Nov 22 2001 schwab@suse.de
- Update to gdb 5.1.
- Build and install gdbserver on i386 and ia64.
* Sat Aug 18 2001 schwab@suse.de
- Update to gdb snapthot 20010316.
* Fri May 18 2001 schwab@suse.de
- Include ia64 warning patches (from nadvornik@suse.cz).
* Thu Apr 12 2001 schwab@suse.de
- Remove declaration of tilde_expand, now in readline header.
* Sat Mar 31 2001 schwab@suse.de
- Fix hardware watchpoints on ia64.
* Fri Mar 30 2001 schwab@suse.de
- Fix crash on info architecture (#6865).
* Wed Mar 28 2001 schwab@suse.de
- Use installed readline library.
* Tue Mar  6 2001 schwab@suse.de
- Remove some ia64 hacks.
* Tue Dec 12 2000 schwab@suse.de
- Improve handling of breakpoints in shared libraries.
* Fri Nov 17 2000 kukuk@suse.de
- Update to working gdb snapshot
* Wed Sep 27 2000 fober@suse.de
- s390: added s390-sigregs-SuSE.patch
* Thu Sep 14 2000 fober@suse.de
- s390: incorporate new ibm patches for gdb 5.0
* Wed Sep  6 2000 fober@suse.de
- s390: incorporate ibm patches for gdb 5.0
* Fri Jun 30 2000 kukuk@suse.de
- Add gdb-5.0
* Tue Apr  4 2000 bk@suse.de
- s390 team added s390 support
* Tue Mar 21 2000 schwab@suse.de
- Fix core dump reading (#2586).
* Fri Feb  4 2000 kukuk@suse.de
- Add patches for PPC
- Move /usr/info -> /usr/share/info
* Mon Dec  6 1999 kukuk@suse.de
- Remove gdb 4.17
- Add gdb 4.18 fixes for SPARC
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Sep  3 1999 kukuk@suse.de
- Use RPM values for CFLAGS and configure
* Tue Aug 24 1999 uli@suse.de
- added -fsigned-char to CFLAGS (PPC)
* Mon Aug 23 1999 kukuk@suse.de
- Add gdb 4.18 thread patch from RH
* Mon Jul 19 1999 florian@suse.de
- add gdb-4.17.0.12 as /usr/bin/gdb-4.17
* Wed Jul  7 1999 kukuk@suse.de
- update to 4.18 using diff from jurix
* Mon Feb 22 1999 ro@suse.de
- update to 4.17.0.11 using diff from jurix
* Thu Jan 21 1999 ro@suse.de
- update to 4.17.0.8
* Thu Oct  1 1998 ro@suse.de
- update to 4.17.0.4 using jurix-diff
* Tue Sep 15 1998 ro@suse.de
- hacked for GLIBC: include sys/ucontext and sys/ptrace where needed
- catch strup redeclarations
- cleaned up patch-sequence
* Tue Oct 28 1997 florian@suse.de
- fix <sys/procfs.h> in libc to correctly support core-files
- add bug-fix to read symbols from dynamic symbol tables
- apply all patches from debian gdb-4.16-11
* Thu Jan  2 1997 florian@suse.de
  Neue Version 4.16.
  gdb kompiliert nur mit libc 5.4.7 richtig. Mit 5.2.18 kann gdb
  keine core-files lesen.
  Ich waere dafuer, einfach das Binary von libc 5.4.7 zu benutzen.
  Wird schon funktionieren...
